<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;
use HCM\Util\HCM;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;
use HCM\Util\Util;

class ImportacaoPlanilhaVinculoRepository {

    protected $connection;
    protected $entityManager;
    protected $hcmParameters;
    protected $perfacessparc;

    public function __construct(Connection $connection, EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->perfacessparc = Repositories::PERFACESSPARC;
    }

    /**
     * @return array
     */
    public function getMaxId() {
      $maxIdQuery = "SELECT LPAD(TO_CHAR(MAX(TO_NUMBER(DECODE(REPLACE(TRANSLATE(CDOPERADOR, '0123456789', '##########'), '#', ''), NULL, CDOPERADOR, NULL)))+1), 12, '0') MAX_ID FROM OPERADOR";
      return $this->connection->fetchAll($maxIdQuery);
    }

    public function deleteImpPlanilhaVinculoPessoa($nrpessoa, $nrorg, $entityManager) {
        if($entityManager)
          $this->entityManager = $entityManager;

        $tables = ['GPE_PESSOAH', 'GPE_PESSOA'];
        
        $params = ["P_NRORG"    => $nrorg,
                   "P_NRPESSOA" => $nrpessoa];

        foreach($tables as $table) {
          $query = $this->entityManager->getConnection()->prepare("
              DELETE FROM $table
              WHERE NRORG    = :P_NRORG
                AND NRPESSOA = :P_NRPESSOA"
          );
          
          $query->execute($params);
        }
    }

    public function novoPerfacessparcAdmissao($data){
      $nrperfacessparc = \HCM\Util\NovoCodigo::geraCodigo($data['NRORG'], 'PERFACESSPARC', 1, 12, true);

      $perfacessparc = new $this->perfacessparc;
      $perfacessparc->setNrperfacessparc($nrperfacessparc);
      $perfacessparc->setNrperfilacesso($data['NRPERFILACESSO']);
      $perfacessparc->setNrparcnegocio($data['NRPARCNEGOCIO']);
      $perfacessparc->setDtvalperfilparc(null);
      $perfacessparc->setIdativo($data['IDATIVO']);
      $perfacessparc->setNrorg($data['NRORG']);
      $perfacessparc->setNrorginclusao($data['NRORG']);
      $perfacessparc->setNrorgultatu($data['NRORG']);
      $perfacessparc->setCdoperinclusao($data['CDOPERINCLUSAO']);
      $perfacessparc->setCdoperultatu($data['CDOPERULTATU']);
      $perfacessparc->setDtinclusao($data['DTINCLUSAO']);
      $perfacessparc->setDtultatu($data['DTULTATU']);

      $this->entityManager->persist($perfacessparc);
      $this->entityManager->flush($perfacessparc);

      unset($perfacessparc);
    }

    public function encontraTurno1($nrorg, $nrescalatrabm) {
                      
      $query = "SELECT NRTURNO
                  FROM GPE_TURNO
                WHERE NRORG   = :P_NRORG
                  AND IDATIVO = :P_IDATIVO
                  AND NRESCALATRABM = :P_NRESCALATRABM
                  AND (UPPER(DSTURNO)    = 'TURNO 1'
                        OR UPPER(DSTURNO) = 'TURNO 01'
                        OR NRTURNO = (SELECT MIN(NRTURNO)
                                        FROM GPE_TURNO
                                      WHERE NRORG   = :P_NRORG
                                        AND IDATIVO = :P_IDATIVO
                                        AND NRESCALATRABM = :P_NRESCALATRABM))
                ORDER BY NRESCALATRABM";

      $params = ['P_NRESCALATRABM' => $nrescalatrabm,
                'P_NRORG' => $nrorg,
                'P_IDATIVO' => 'S'];
                    
      return $this->connection->fetchAssoc($query, $params);
    }

    public function getBeneficioImpVinc($nrorg, $nrorgpadarao, $nrestrutsind, $dtmescompetenc) {
      
      $query = <<<SQL
SELECT
    BNM.NRBENEFICIOM                    AS NRBENEFICIOM,
    BNH.NRBENEFICIOH                    AS NRBENEFICIOH,
    BNH.DSBENEFICIO                     AS DSBENEFICIO,
    BNH.NRTPBENEFICIO                   AS NRTPBENEFICIO,
    BNH.DTMESCOMPETENC                  AS DTMESCOMPETENC,
    BNM.DTINICIOVIGENCIA                AS DTINICIOVIGENCIA,
    BNM.DTFINALVIGENCIA                 AS DTFINALVIGENCIA,
    BNH.TPPERIODOBENEF                  AS TPPERIODOBENEF,
    BNH.NREVENTOMENSADEP                AS NREVENTOMENSADEP,
    EVH_MENS_DEP.NMEVENTOH              AS NMEVENTOMENSADEP,
    BNH.NRESTRUTURAM                    AS NRESTRUTURAM,
    EST.NMESTRUTURAH                    AS NMESTRUTURAH,
    ESTSIND.NMESTRUTURAH                AS NMESTRUTSIND,
    BNH.NRORG                           AS NRORG,
    BNH.IDATIVO                         AS IDATIVO,
    BNM.NRORGINCLUSAO                   AS NRORGINCLUSAO,
    BNM.DTINCLUSAO                      AS DTINCLUSAO,
    BNM.CDOPERINCLUSAO                  AS CDOPERINCLUSAO,
    BNH.NRORGULTATU                     AS NRORGULTATU,
    BNH.DTULTATU                        AS DTULTATU,
    BNH.CDOPERULTATU                    AS CDOPERULTATU
FROM
    VAB_BENEFICIOM BNM
    LEFT JOIN VAB_BENEFICIOH BNH     ON BNH.NRBENEFICIOM = BNM.NRBENEFICIOM
                                    AND BNM.NRORG = BNH.NRORG
                                    AND BNH.DTMESCOMPETENC = (SELECT DTMESCOMPETENC
                                                                FROM (SELECT BNEH.DTMESCOMPETENC
                                                                        FROM VAB_BENEFICIOH BNEH
                                                                       WHERE BNEH.NRORG = BNH.NRORG
                                                                         AND BNEH.NRBENEFICIOM = BNH.NRBENEFICIOM
                                                                         AND BNEH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                                    ORDER BY BNEH.DTMESCOMPETENC DESC)
                                                              WHERE ROWNUM = 1)
    JOIN TPBENEFICIO    TPB ON TPB.NRTPBENEFICIO = BNH.NRTPBENEFICIO
                            AND ( TPB.NRORG = BNH.NRORG
                                  OR TPB.NRORG = :P_NRORG_PADRAO )
    JOIN FORMABENEFICIO FB ON FB.NRFORMABENEFICIO = BNH.NRFORMABENEFICIO
                              AND ( FB.NRORG = BNH.NRORG
                                    OR FB.NRORG = :P_NRORG_PADRAO )
    LEFT JOIN ESTRUTURAH     EST ON EST.NRESTRUTURAM = BNH.NRESTRUTURAM
                                AND EST.NRORG = BNH.NRORG
                                AND EST.DTMESCOMPETENC = (SELECT DTMESCOMPETENC
                                                            FROM (SELECT ESTH.DTMESCOMPETENC
                                                                    FROM ESTRUTURAH ESTH
                                                                   WHERE ESTH.NRORG = EST.NRORG
                                                                     AND ESTH.NRESTRUTURAM = EST.NRESTRUTURAM
                                                                     AND ESTH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                                ORDER BY ESTH.DTMESCOMPETENC DESC)
                                                          WHERE ROWNUM = 1)
    LEFT JOIN ESTRUTURAH     ESTSIND ON ESTSIND.NRESTRUTURAM = BNH.NRESTRUTSIND
                                    AND ESTSIND.NRORG = BNH.NRORG
                                    AND ESTSIND.DTMESCOMPETENC = (SELECT DTMESCOMPETENC
                                                                    FROM (SELECT ESTH.DTMESCOMPETENC
                                                                            FROM ESTRUTURAH ESTH
                                                                           WHERE ESTH.NRORG = ESTSIND.NRORG
                                                                             AND ESTH.NRESTRUTURAM = ESTSIND.NRESTRUTURAM
                                                                             AND ESTH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                                        ORDER BY ESTH.DTMESCOMPETENC DESC)
                                                                WHERE ROWNUM = 1)
    LEFT JOIN FPA_EVENTOH    EVH_MENS_DEP ON EVH_MENS_DEP.NREVENTOM = BNH.NREVENTOMENSADEP
                                          AND ( EVH_MENS_DEP.NRORG = BNM.NRORG
                                                OR EVH_MENS_DEP.NRORG = :P_NRORG_PADRAO )
                                          AND EVH_MENS_DEP.DTMESCOMPETENC = (SELECT DTMESCOMPETENC
                                                                               FROM (SELECT SUB_EVENTH.DTMESCOMPETENC
                                                                                       FROM FPA_EVENTOH SUB_EVENTH
                                                                                      WHERE SUB_EVENTH.NRORG = EVH_MENS_DEP.NRORG
                                                                                        AND SUB_EVENTH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                                                        AND SUB_EVENTH.NREVENTOM = EVH_MENS_DEP.NREVENTOM
                                                                                   ORDER BY DTMESCOMPETENC DESC)
                                                                             WHERE ROWNUM = 1)
WHERE BNM.NRORG        = :P_NRORG
  AND BNH.NRESTRUTSIND = :P_NRESTRUTSIND
  AND BNH.IDATIVO      = :P_IDATIVO
SQL;

      $params = ["P_NRORG"          => $nrorg,
                 "P_NRORG_PADRAO"   => $nrorgpadarao,
                 "P_NRESTRUTSIND"   => $nrestrutsind,
                 "P_DTMESCOMPETENC" => $dtmescompetenc,
                 "P_IDATIVO"        => 'S'];
      
      return $this->connection->fetchAll($query, $params);
    }

    public function getTipoBeneficioGerencialVigenteImpVinc($nrorg, $nrestrutgeren, $dtmescompetenc) {

      $query = "SELECT *
                  FROM TPBENEFICIOGERENCIAL
                 WHERE NRORG = :P_NRORG
                   AND NRESTRUTGEREN    = :P_NRESTRUTGEREN
                   AND DTINIVIGENCIA   <= :P_DTMESCOMPETENC
                   AND ( DTFIMVIGENCIA >= LAST_DAY(:P_DTMESCOMPETENC)
                          OR DTFIMVIGENCIA IS NULL )
                   AND IDATIVO = :P_IDATIVO";

      $params = ["P_NRORG"          => $nrorg,
                 "P_NRESTRUTGEREN"  => $nrestrutgeren,
                 "P_DTMESCOMPETENC" => $dtmescompetenc,
                 "P_IDATIVO"        => 'S'];
      
      return $this->connection->fetchAll($query, $params);                                                 
    }
  
}