<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class PreFechamentoDctfWebRepository {
    
    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->contribuicaoPrevidenciariaSegurado = new ContribuicaoPrevidenciariaSegurado($entityManager);
        $this->informacoesSinteticas = new InformacoesSinteticas($entityManager);
        $this->informacoesSobreBasesCalculo = new InformacoesSobreBasesCalculo($entityManager);
    }
        
    public function getContribuicaoPrevidenciariaSegurado($parameters) {
        return $this->contribuicaoPrevidenciariaSegurado->getContribuicao($parameters);
    }
    
    public function getEventosApuradosContribuicao($parameters) {
        return $this->contribuicaoPrevidenciariaSegurado->getEventosApurados($parameters);
    }
        
    public function getInformacoesSinteticas($parameters) {
        return $this->informacoesSinteticas->getInformacoesSinteticas($parameters);
    }
    
    public function getInformacoesSobreBasesCalculo($parameters) {
        return $this->informacoesSobreBasesCalculo->getInformacoesSobreBasesCalculo($parameters);
    }
}

class ContribuicaoPrevidenciariaSegurado {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getContribuicao($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryContribuicaoPrevidenciariaSegurado);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_MODALIDADECAL' => 1,
                'P_NRTABELA'      => $parameters['NRTABELA'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRESTRUTGEREN' => $parameters['NRESTRUTGEREN'],
                'P_NRVINCULO'     => '',
                'P_IDDIFERENCA'   => $parameters['IDDIFERENCA'],
            )
        );
        return $sql->fetchAll();
    }
    
    public function getEventosApurados($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryEventosApuradosContribuicao);
        $sql->execute(
            array( 
                'P_NRORG'             => $parameters['NRORG'],
                'P_COMPETENCIA'       => $parameters['COMPETENCIA'],
                'P_MODALIDADECAL'     => 1,
                'P_NRVINCULOM'        => $parameters['NRVINCULOM'],
                'P_NRTABELA'          => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSinteticas {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSinteticas($parameters) {
        
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryInformacoesSinteticas);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_MODALIDADECAL' => 1,
                'P_NRESTRUTGEREN' => $parameters['NRESTRUTGEREN'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSobreBasesCalculo {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSobreBasesCalculo($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryInformacoesSobreBasesCalculo);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class Queries {
    
    static $queryContribuicaoPrevidenciariaSegurado = "
/*queryContribuicaoPrevidenciariaSegurado_cte*/
WITH
ULT_COMP_VINC AS (
    SELECT 
        NRORG, 
        NRVINCULOM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM GPE_VINCULOH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_COMPETENCIA
    GROUP BY NRORG, NRVINCULOM
),
ULT_COMP_ESTRUT AS (
    SELECT 
        NRORG, 
        NRESTRUTURAM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM ESTRUTURAH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_COMPETENCIA
    GROUP BY NRORG, NRESTRUTURAM
),
VINCULOS AS (
    SELECT
        VM.NRORG, 
        VM.NRPESSOA,
        VM.NRVINCULOM,
        VM.DTRESCISAOVINC,
        NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM) AS MATRICULA,
        VM.NMVINCULOM,
        VM.NRTIPOVINCULOM,
        VH.NRESTRUTLEGAL AS NRLEGAL,
        VH.NRESTRUTGEREN AS NRGEREN,
        EHL.NMRAZSOCESTRUT AS RAZAOLEGAL,
        EHL.CDCNPJESTRUT AS CNPJLEGAL,
        CATEGTRAB.DSCATEGESOC,
        CATEGTRAB.CDESOCIAL,
        EP.NRTPAMBIENTE
    FROM GPE_VINCULOM VM
    JOIN ULT_COMP_VINC UCV ON UCV.NRORG = VM.NRORG
                          AND UCV.NRVINCULOM = VM.NRVINCULOM
    JOIN GPE_VINCULOH VH ON VH.NRORG = UCV.NRORG
                        AND VH.NRVINCULOM = UCV.NRVINCULOM
                        AND VH.DTMESCOMPETENC = UCV.DTMESCOMPETENC
    JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = VH.NRORG
                            AND UCE.NRESTRUTURAM = VH.NRESTRUTLEGAL
    JOIN ESTRUTURAH EHL ON EHL.NRORG = UCE.NRORG
                       AND EHL.NRESTRUTURAM = UCE.NRESTRUTURAM
                       AND EHL.DTMESCOMPETENC = UCE.DTMESCOMPETENC
    JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
    JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
    JOIN ESO_PARAMETRO EP ON EP.NRORG = EHL.NRORG
                         AND EP.NRESTRUTURAM = EHL.NRESTRUTURAM
    WHERE VM.NRORG = :P_NRORG
      AND (VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA))
      AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL)
      AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
      AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
      AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
)
SELECT * FROM (
    SELECT
        RES.NRVINCULOM,
        RES.DTRESCISAOVINC,
        RES.MATRICULA,
        PE.NRCPFPESSOA,
        PE.NRCPFPESSOA||' - '||RES.NMVINCULOM PESSOA,
        RES.NMVINCULOM,
        RES.NRLEGAL,
        RES.NRGEREN,
        RES.RAZAOLEGAL,
        RES.CNPJLEGAL,
        NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0) VRDESC_ESO,
        NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0) VRCALCULADO_ESO,
        SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) VRBASE_ESO,
        SUM(CAL.BASE) BASE,
        SUM(CAL.INSS) INSS,
        NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
        NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), CAL.NRTABELA) NRTABELA,
        NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO) NMEVENTO,
        SUM(CAL.BASE) - SUM(NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASEMENSAL,0) + NVL(ESONP.VRBASEMENSAL,0)) DIFERENCA_BASE,
        SUM(CAL.INSS) - SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) DIFERENCA_DESCONTO,
        :P_COMPETENCIA PERIODO,
        SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
        RES.CDESOCIAL CDCATEGESOC,
        (RES.CDESOCIAL || ' - '|| RES.DSCATEGESOC) DSCATEGESOC
    FROM VINCULOS RES
    JOIN GPE_PESSOAH PE
      ON PE.NRPESSOA = RES.NRPESSOA 
     AND PE.NRORG = RES.NRORG 
     AND PE.DTMESCOMPETENC = ( SELECT *
                                FROM ( SELECT DTMESCOMPETENC 
                                       FROM GPE_PESSOAH
                                       WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                         AND NRORG        = PE.NRORG
                                         AND NRPESSOA = PE.NRPESSOA 
                                        ORDER BY DTMESCOMPETENC DESC )
                                WHERE ROWNUM = 1 )
    LEFT JOIN (SELECT CF.DTOCORRENCIA,
                        CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                             WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                        END NRTABELA,
                        ICF.NRVINCULOM,
                        SUM(CASE WHEN ICF.NREVENTOM IN (3070 ,3075 ,3130, 3190, 3211, 4010) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                        SUM(CASE WHEN ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000) THEN ICF.VREVENTOFOLHA ELSE 0 END) INSS
                   FROM FPA_CALCULOFOLHA CF
                   JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG = CF.NRORG
                                            AND ICF.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                                            AND ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000, 3070 ,3075 ,3130, 3190, 3211, 4010)
                                            AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                         WHERE IC.NRORG = ICF.NRORG
                                                           AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                           AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                           AND IC.NREVENTOM IN (3030, 3050))
                  WHERE CF.NRORG = :P_NRORG
                    AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                         (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                         (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                    AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                    AND CF.DTOCORRENCIA = :P_COMPETENCIA
                  GROUP BY CF.DTOCORRENCIA,
                           CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                                WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                           END,
                           ICF.NRVINCULOM
            ) CAL ON CAL.NRVINCULOM = RES.NRVINCULOM
    LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                        ESONP.NRTPAMBIENTE,
                        ESONP.NRVINCULOM,
                        NPCP.CDMATRICULA,
                        ESONP.NRORG,
                        ESONP.NRESTRUTURAM,
                        ESONP.IDSTATUS,
                        NVL(ESONP.NRTABELA, 1) NRTABELA,
                        ESONP.NMEVENTO,
                        NVL(NPCP.VRDESCONTADO, 0) AS VRDESCONTADO,
                        NVL(NPCP.VRCALCULADO, 0) AS VRCALCULADO,
                        NVL(NPCP.VRBASE13,0) AS VRBASE13,
                        NVL(NPCP.VRBASEMENSAL,0) AS VRBASEMENSAL,
                        ESONP.NRENVIO,
                        EHPN.CDCNPJESTRUT
                FROM ESO_NAOPERIODICO ESONP 
                JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = ESONP.NRORG
                                        AND UCE.NRESTRUTURAM = ESONP.NRESTRUTURAM
                JOIN ESTRUTURAH EHPN ON EHPN.NRORG = UCE.NRORG
                                    AND EHPN.NRESTRUTURAM = UCE.NRESTRUTURAM
                                    AND EHPN.DTMESCOMPETENC = UCE.DTMESCOMPETENC
                JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                        AND NPCP.NRENVIO = ESONP.NRENVIO
                WHERE ESONP.NRORG = :P_NRORG
                AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                AND ESONP.IDSTATUS IN('C','A')
                AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESONP.NMEVENTO IN ('S-2299','S-2399')
            ) ESONP ON ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESONP.NRVINCULOM = RES.NRVINCULOM
                   AND (ESONP.CDMATRICULA = RES.MATRICULA OR ESONP.CDMATRICULA IS NULL)
                   AND ESONP.DTMESCOMPETENC = RES.DTRESCISAOVINC
                   AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ((TRUNC(ESONP.DTMESCOMPETENC, 'MM') = CAL.DTOCORRENCIA AND ESONP.NRTABELA = CAL.NRTABELA) OR CAL.DTOCORRENCIA IS NULL)
    LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                    ESOPE.NRTPAMBIENTE,
                    ESOPE.NRCHAVE,
                    PECP.CDMATRICULA,
                    ESOPE.NRORG,
                    ESOPE.NRESTRUTURAM,
                    ESOPE.IDSTATUS,
                    ESOPE.NRTABELA,
                    ESOPE.NMEVENTO,
                    NVL(PECP.VRDESCONTADO,0) AS VRDESCONTADO,
                    NVL(PECP.VRCALCULADO,0) AS VRCALCULADO,
                    NVL(PECP.VRBASE13,0) AS VRBASE13,
                    NVL(PECP.VRBASEMENSAL,0) AS VRBASEMENSAL,
                    ESOPE.NRENVIO,
                    EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE
                JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = ESOPE.NRORG
                                        AND UCE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG = UCE.NRORG
                                    AND EHPE.NRESTRUTURAM = UCE.NRESTRUTURAM
                                    AND EHPE.DTMESCOMPETENC = UCE.DTMESCOMPETENC
                JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                        AND PECP.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESOPE.NMEVENTO = 'S-1200'
            ) ESOPE ON ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND (ESOPE.CDMATRICULA = RES.MATRICULA OR ESOPE.CDMATRICULA IS NULL)
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ((TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = CAL.DTOCORRENCIA AND ESOPE.NRTABELA = CAL.NRTABELA) OR CAL.DTOCORRENCIA IS NULL)
    GROUP BY RES.NRVINCULOM,
            RES.DTRESCISAOVINC,
            RES.MATRICULA,
            PE.NRCPFPESSOA,
            RES.NMVINCULOM,
            RES.NRLEGAL,
            RES.NRGEREN,
            RES.RAZAOLEGAL,
            RES.CNPJLEGAL,
            NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS),
            NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), CAL.NRTABELA),
            NVL(ESOPE.NMEVENTO,ESONP.NMEVENTO),
            NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0),
            NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0),
            RES.DSCATEGESOC,
            RES.CDESOCIAL
    )
WHERE ( BASE IS NOT NULL OR NMEVENTO IS NOT NULL )
  AND ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_DESCONTO) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_DESCONTO) > 0.05 )) 
      )";
    
    static $queryContribuicaoPrevidenciariaSegurado_old = "
/*queryContribuicaoPrevidenciariaSegurado*/
SELECT * FROM (
    SELECT RES.NRVINCULOM,
        RES.DTRESCISAOVINC,
        RES.MATRICULA,
        PE.NRCPFPESSOA,
        PE.NRCPFPESSOA||' - '||RES.NMVINCULOM PESSOA,
        RES.NMVINCULOM,
        RES.NRLEGAL,
        RES.NRGEREN,
        RES.RAZAOLEGAL,
        RES.CNPJLEGAL,
        RES.INTLEGAL,
        RES.RAZAOGEREN,
        RES.CNPJGEREN,
        RES.INTGEREN,
        NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0) VRDESC_ESO,
        NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0) VRCALCULADO_ESO,
        SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) VRBASE_ESO,
        SUM(RES.BASE) BASE,
        SUM(RES.INSS) INSS,
        NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
        NVL(ESOPE.NRTABELA, ESONP.NRTABELA) NRTABELA,
        NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO) NMEVENTO,
        SUM(RES.BASE) - SUM(NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASEMENSAL,0) + NVL(ESONP.VRBASEMENSAL,0)) DIFERENCA_BASE,
        SUM(RES.INSS) - SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) DIFERENCA_DESCONTO,
        :P_COMPETENCIA PERIODO,
        SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
        RES.CDESOCIAL CDCATEGESOC,
        (RES.CDESOCIAL || ' - '|| RES.DSCATEGESOC) DSCATEGESOC
      FROM (SELECT
                VM.NRORG, 
                VM.NRPESSOA,
                VM.NRVINCULOM,
                VM.DTRESCISAOVINC,
                NVL(VH.CDMATRICULAESOCIAL,VM.NRVINCULOM) MATRICULA, 
                VM.NMVINCULOM,
                VM.NRTIPOVINCULOM,
                SUM(CASE WHEN ICF.NREVENTOM IN (3070 ,3075 ,3130, 3190, 3211, 4010) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                SUM(CASE WHEN ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000) THEN ICF.VREVENTOFOLHA ELSE 0 END) INSS,
                CF.DTOCORRENCIA,
                CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                     WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                END NRTABELA,
                VH.NRESTRUTLEGAL   NRLEGAL,
                VH.NRESTRUTGEREN   NRGEREN,
                EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                EHL.CDCNPJESTRUT   CNPJLEGAL,
                EML.CDINTESTRUTURA INTLEGAL,
                EHG.NMRAZSOCESTRUT RAZAOGEREN,
                EHG.CDCNPJESTRUT   CNPJGEREN,
                EMG.CDINTESTRUTURA INTGEREN,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL,
                EP.NRTPAMBIENTE
              FROM GPE_VINCULOM VM
              JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                  AND VH.NRVINCULOM = VM.NRVINCULOM
                                  AND VH.DTMESCOMPETENC = ( SELECT *
                                                              FROM ( SELECT DTMESCOMPETENC
                                                                     FROM GPE_VINCULOH
                                                                     WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                       AND NRORG      = VH.NRORG
                                                                       AND NRVINCULOM = VH.NRVINCULOM
                                                                     ORDER BY DTMESCOMPETENC DESC )
                                                               WHERE ROWNUM = 1 )
              /*ESTRUTURA LEGAL*/
              JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                      AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
              LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                      AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                      AND EHL.DTMESCOMPETENC = ( SELECT *
                                                                    FROM ( SELECT DTMESCOMPETENC 
                                                                           FROM ESTRUTURAH
                                                                           WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                             AND NRORG        = VH.NRORG
                                                                             AND NRESTRUTURAM = EML.NRESTRUTURAM 
                                                                            ORDER BY DTMESCOMPETENC DESC )
                                                                    WHERE ROWNUM = 1 )
              /*ESTRUTURA GERENCIAL*/
              JOIN ESTRUTURAM EMG ON EMG.NRORG        = VH.NRORG
                                      AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
              LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG        = VH.NRORG
                                      AND EHG.NRESTRUTURAM = EMG.NRESTRUTURAM
                                      AND EHG.DTMESCOMPETENC = ( SELECT *
                                                                    FROM ( SELECT DTMESCOMPETENC 
                                                                           FROM ESTRUTURAH
                                                                           WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                             AND NRORG        = VH.NRORG
                                                                             AND NRESTRUTURAM = EMG.NRESTRUTURAM 
                                                                            ORDER BY DTMESCOMPETENC DESC )
                                                                    WHERE ROWNUM = 1 )
              /*CÁLCULO DE FOLHA*/
              JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                      AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                      AND ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000, 3070 ,3075 ,3130, 3190, 3211, 4010)
                                      AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                   WHERE IC.NRORG = ICF.NRORG
                                                     AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                     AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                     AND IC.NREVENTOM IN (3030, 3050))
              JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = ICF.NRORG
                                      AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                      AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                                           (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                                           (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                      AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                      AND CF.DTOCORRENCIA   = :P_COMPETENCIA
              /*CATEGORIA*/
              JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
              JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
              
              JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                             AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
              /**/
              WHERE VM.NRORG = :P_NRORG
                AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
              GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM,
                VM.DTRESCISAOVINC,
                NVL(VH.CDMATRICULAESOCIAL,VM.NRVINCULOM),
                VM.NMVINCULOM,
                VM.NRTIPOVINCULOM,
                CF.DTOCORRENCIA,
                CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                     WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                END,
                /*ICF.VREVENTOFOLHA,*/
                /*ICF.NREVENTOM,*/
                VH.NRESTRUTLEGAL,
                VH.NRESTRUTGEREN,
                EHL.NMRAZSOCESTRUT,
                EHL.CDCNPJESTRUT,
                EML.CDINTESTRUTURA,
                EHG.NMRAZSOCESTRUT,
                EHG.CDCNPJESTRUT,
                EMG.CDINTESTRUTURA,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL,
                EP.NRTPAMBIENTE
            ) RES
      LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                    ESONP.NRTPAMBIENTE,
                    ESONP.NRVINCULOM,
                    NPCP.CDMATRICULA,
                    ESONP.NRORG,
                    ESONP.NRESTRUTURAM,
                    ESONP.IDSTATUS,
                    NVL(ESONP.NRTABELA, 1) NRTABELA,
                    ESONP.NMEVENTO,
                    NVL(NPCP.VRDESCONTADO, 0) AS VRDESCONTADO,
                    NVL(NPCP.VRCALCULADO, 0) AS VRCALCULADO,
                    NVL(NPCP.VRBASE13,0) AS VRBASE13,
                    NVL(NPCP.VRBASEMENSAL,0) AS VRBASEMENSAL,
                    ESONP.NRENVIO,
                    EHPN.CDCNPJESTRUT
                FROM ESO_NAOPERIODICO ESONP 
                JOIN ESTRUTURAH EHPN ON EHPN.NRORG   = ESONP.NRORG
                                          AND EHPN.NRESTRUTURAM = ESONP.NRESTRUTURAM
                                          AND EHPN.DTMESCOMPETENC = ( SELECT * FROM (SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESONP.NRORG
                                                                      AND NRESTRUTURAM = EHPN.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                        AND NPCP.NRENVIO = ESONP.NRENVIO
                WHERE ESONP.NRORG = :P_NRORG
                AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                AND ESONP.IDSTATUS IN('C','A')
                AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                
            )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESONP.NRVINCULOM = RES.NRVINCULOM
                   AND (ESONP.CDMATRICULA = RES.MATRICULA OR ESONP.CDMATRICULA IS NULL)
                   AND ESONP.DTMESCOMPETENC = RES.DTRESCISAOVINC
                   AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ESONP.NRTABELA = RES.NRTABELA
                                  
     LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                ESOPE.NRTPAMBIENTE,
                ESOPE.NRCHAVE,
                PECP.CDMATRICULA,
                ESOPE.NRORG,
                ESOPE.NRESTRUTURAM,
                ESOPE.IDSTATUS,
                ESOPE.NRTABELA,
                ESOPE.NMEVENTO,
                NVL(PECP.VRDESCONTADO,0) AS VRDESCONTADO,
                NVL(PECP.VRCALCULADO,0) AS VRCALCULADO,
                NVL(PECP.VRBASE13,0) AS VRBASE13,
                NVL(PECP.VRBASEMENSAL,0) AS VRBASEMENSAL,
                ESOPE.NRENVIO,
                EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE   
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG   = ESOPE.NRORG
                                          AND EHPE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                                          AND EHPE.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESOPE.NRORG
                                                                      AND NRESTRUTURAM = EHPE.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                        AND PECP.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESOPE.NMEVENTO = 'S-1200'
                
            )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND (ESOPE.CDMATRICULA = RES.MATRICULA OR ESOPE.CDMATRICULA IS NULL)
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ESOPE.NRTABELA = RES.NRTABELA
      JOIN GPE_PESSOAH PE
              ON PE.NRPESSOA = RES.NRPESSOA 
              AND PE.NRORG = RES.NRORG 
              AND PE.DTMESCOMPETENC = ( SELECT *
                                        FROM ( SELECT DTMESCOMPETENC 
                                               FROM GPE_PESSOAH
                                               WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                 AND NRORG        = PE.NRORG
                                                 AND NRPESSOA = PE.NRPESSOA 
                                                ORDER BY DTMESCOMPETENC DESC )
                                        WHERE ROWNUM = 1 )
      GROUP BY RES.NRVINCULOM,
        RES.DTRESCISAOVINC,
        RES.MATRICULA,
        PE.NRCPFPESSOA,
        RES.NMVINCULOM,
        RES.NRLEGAL,
        RES.NRGEREN,
        RES.RAZAOLEGAL,
        RES.CNPJLEGAL,
        RES.INTLEGAL,
        RES.RAZAOGEREN,
        RES.CNPJGEREN,
        RES.INTGEREN,
        NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS),
        NVL(ESOPE.NRTABELA, ESONP.NRTABELA),
        NVL(ESOPE.NMEVENTO,ESONP.NMEVENTO),
        NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0),
        NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0),
        RES.DSCATEGESOC,
        RES.CDESOCIAL
    )
WHERE ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_DESCONTO) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_DESCONTO) > 0.05 )) 
      )";
    
    static $queryEventosApuradosContribuicao = "
/*queryEventosApuradosContribuicao*/
SELECT
       CF.NRCALCULOFOLHA||' - '||TM.NMTIPOMOVIMENT||' - '||TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY')||' - Ocorrência:'||CF.NROCORRECAL PROCESSO,
       EH.NREVENTOM,
       EH.NMEVENTOH,
       TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY') PERIODO,
       TO_CHAR(ICF.DTOCORRENCIA, 'DD/MM/YYYY') DTOCORRENCIA,
       CF.NROCORRECAL,
       ICF.VREVENTOFOLHA,
       DECODE(EH.IDEVENTODEMONST,'S','3',DECODE(EM.IDTIPOEVENTO,'PROVENTO','1','DESCONTO','2','ENCARGO','3','TOTAL','3')) IDTPRUBRICA,
       RU.CDINCIDECP,
       DECODE(EH.NRNATURUBR, NULL, 'Sem parametrização', CP.DSINCIDCP) INCIDECP
  FROM FPA_ITECALCFOLHA ICF
  JOIN FPA_CALCULOFOLHA CF 
    ON CF.NRORG = ICF.NRORG
   AND CF.NRCALCULOFOLHA  = ICF.NRCALCULOFOLHA
   AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
         (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
         (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
   AND CF.NRTPMODALIDCAL  = :P_MODALIDADECAL
   AND CF.DTOCORRENCIA    = :P_COMPETENCIA
  JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  JOIN FPA_EVENTOM EM ON (EM.NREVENTOM = ICF.NREVENTOM)
  JOIN FPA_EVENTOH EH ON (EH.NREVENTOM = EM.NREVENTOM)
  JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NREVENTOM
          FROM FPA_EVENTOH 
         WHERE DTMESCOMPETENC <= :P_COMPETENCIA
         GROUP BY NREVENTOM) EHATUAL 
            ON ( EHATUAL.NREVENTOM = EH.NREVENTOM
           AND EHATUAL.DTMESCOMPETENC = EH.DTMESCOMPETENC)
  LEFT JOIN ESO_RUBRICA RU ON (RU.NRORG = ICF.NRORG OR RU.NRORG = 0)
                          AND RU.NREVENTOM = EM.NREVENTOM
                          AND RU.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  LEFT JOIN INCIDENCIACP CP ON CP.CDESOCIAL = RU.CDINCIDECP
 WHERE ICF.NRORG = :P_NRORG
   AND ICF.NRVINCULOM = :P_NRVINCULOM
    ";
    
    static $queryInformacoesSinteticas = "
/*queryInformacoesSinteticas*/
SELECT * FROM (
      SELECT 
        NRLEGAL,
        RAZAOLEGAL,
        ('('||NRLEGAL||') '||RAZAOLEGAL) ESTABELECIMENTO,
        CNPJLEGAL,
        INTLEGAL,
        CNPJRAIZ,
        TAB.CODIGO, TAB.DESCRICAO,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN BASE
            WHEN TAB.CODIGO = '02' THEN INSS
            WHEN TAB.CODIGO = '03' THEN FAMILIA
            WHEN TAB.CODIGO = '04' THEN MATERNIDADE
            END
        ) VR_SISTEMA,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN VRBASE_ESO
            WHEN TAB.CODIGO = '02' THEN VRCALCULADO_ESO
            WHEN TAB.CODIGO = '03' THEN VRFAMILIA_ESO
            WHEN TAB.CODIGO = '04' THEN VRMATERNIDADE_ESO
            END
        ) VR_ESOCIAL,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN DIFERENCA_BASE
            WHEN TAB.CODIGO = '02' THEN DIFERENCA_DESCONTO
            WHEN TAB.CODIGO = '03' THEN DIFERENCA_FAMILIA
            WHEN TAB.CODIGO = '04' THEN DIFERENCA_MATERNIDADE
            END
        ) VR_DIFERENCA
      FROM (SELECT RES.NRORG, RES.NRPESSOA, RES.NRLEGAL,
                  RES.RAZAOLEGAL,
                  RES.CNPJLEGAL,
                  RES.INTLEGAL,
                  SUM(NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0)) VRDESC_ESO,
                  SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0))  VRCALCULADO_ESO,
                  SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) VRBASE_ESO,
                  SUM(NVL(ESONP.VRVALORMATER13,0) + NVL(ESONP.VRVALORMATERMENSAL,0) + NVL(ESOPE.VRVALORMATER13,0) + NVL(ESOPE.VRVALORMATERMENSAL,0)) VRMATERNIDADE_ESO,
                  SUM(NVL(ESONP.VRSALFAMILIA13,0) + NVL(ESONP.VRSALFAMILIA,0) + NVL(ESOPE.VRSALFAMILIA13,0) + NVL(ESOPE.VRSALFAMILIA,0)) VRFAMILIA_ESO,
                  SUM(RES.BASE - RES.MATERNIDADE) BASE,
                  RES.INSS,
                  RES.MATERNIDADE,
                  RES.FAMILIA,
                  SUM(RES.BASE - RES.MATERNIDADE) - SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) DIFERENCA_BASE,
                  RES.INSS - SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) DIFERENCA_DESCONTO,
                  RES.MATERNIDADE - SUM(NVL(ESONP.VRVALORMATER13,0) + NVL(ESONP.VRVALORMATERMENSAL,0) + NVL(ESOPE.VRVALORMATER13,0) + NVL(ESOPE.VRVALORMATERMENSAL,0)) DIFERENCA_MATERNIDADE,
                  RES.FAMILIA - SUM(NVL(ESONP.VRSALFAMILIA13,0) + NVL(ESONP.VRSALFAMILIA,0) + NVL(ESOPE.VRSALFAMILIA13,0) + NVL(ESOPE.VRSALFAMILIA,0)) DIFERENCA_FAMILIA,
                  :P_COMPETENCIA PERIODO,
                  SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ
             FROM (SELECT
                      VM.NRORG, VM.NRPESSOA,
                      VM.NRVINCULOM,
                      CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                           WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                      END NRTABELA,
                      NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM)     MATRICULA,
                      SUM(CASE WHEN ICF.NREVENTOM IN (3070 ,3075 ,3130, 3190, 3211, 4010) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                      SUM(CASE WHEN ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000/*, 1140, 1190*/) THEN ICF.VREVENTOFOLHA ELSE 0 END) INSS,
                      SUM(CASE WHEN ICF.NREVENTOM IN (330, 331) THEN ICF.VREVENTOFOLHA ELSE 0 END) MATERNIDADE,
                      SUM(CASE WHEN ICF.NREVENTOM IN (300) THEN ICF.VREVENTOFOLHA ELSE 0 END) FAMILIA,
                      CF.DTOCORRENCIA,
                      VH.NRESTRUTLEGAL   NRLEGAL,
                      EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                      EHL.CDCNPJESTRUT   CNPJLEGAL,
                      EML.CDINTESTRUTURA INTLEGAL,
                      EP.NRTPAMBIENTE,
                      VM.DTRESCISAOVINC
                    FROM GPE_VINCULOM VM
                    JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                        AND VH.NRVINCULOM = VM.NRVINCULOM
                                        AND VH.DTMESCOMPETENC = ( SELECT *
                                              FROM ( SELECT DTMESCOMPETENC
                                                     FROM GPE_VINCULOH
                                                     WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                       AND NRORG      = VH.NRORG
                                                       AND NRVINCULOM = VH.NRVINCULOM
                                                     ORDER BY DTMESCOMPETENC DESC )
                                               WHERE ROWNUM = 1 )
                    /*ESTRUTURA LEGAL*/
                    JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                            AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                            AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = ( SELECT DTMESCOMPETENC FROM(SELECT DTMESCOMPETENC FROM ESTRUTURAH
                                                                       WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                         AND NRORG        = VH.NRORG
                                                                         AND NRESTRUTURAM = EML.NRESTRUTURAM 
                                                                         ORDER BY DTMESCOMPETENC) WHERE ROWNUM = 1)
                                                                         
                   JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                                        AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
                    /*CÁLCULO DE FOLHA*/
                    JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                             AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                             AND ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000, 3070 ,3075 ,3130, 3190, 3211, 4010/*1140,1190*/, 300, 330, 331)
                                             AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                          WHERE IC.NRORG = ICF.NRORG
                                                            AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                            AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                            AND IC.NREVENTOM IN (3030, 3050))
                    JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = ICF.NRORG
                                            AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                            AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                                                 (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                                                 (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                            AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                            AND CF.DTOCORRENCIA   = :P_COMPETENCIA
                    /**/
                    WHERE VM.NRORG = :P_NRORG
                      AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                      AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                      AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                      AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                      AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
                    GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM, VM.NMVINCULOM, VM.DTADMISSAOVINC, VM.DTRESCISAOVINC, VM.NRTIPOVINCULOM,
                      CF.DTOCORRENCIA,
                      VH.NRESTRUTLEGAL,
                      EHL.NMRAZSOCESTRUT,
                      EHL.CDCNPJESTRUT,
                      EML.CDINTESTRUTURA,
                      EP.NRTPAMBIENTE,
                      CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                           WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                      END,
                      NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM),
                      VM.DTRESCISAOVINC
                      ) RES
                LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                                  ESONP.NRTPAMBIENTE,
                                  ESONP.NRVINCULOM,
                                  ESONP.NRESTRUTURAM,
                                  NVL(ESONP.NRTABELA, 1) NRTABELA,
                                  NPCP.CDMATRICULA,
                                  SUM(NVL(NVL(NPCP.VRDESCONTADO,ESONP.VRDESCONTADO),0)) AS VRDESCONTADO,
                                  SUM(NVL(NVL(NPCP.VRCALCULADO,ESONP.VRCALCULADO),0)) AS VRCALCULADO,
                                  SUM(NVL(NVL(NPCP.VRBASE13,ESONP.VRBASE13),0)) AS VRBASE13,
                                  SUM(NVL(NVL(NPCP.VRBASEMENSAL,ESONP.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                                  SUM(NVL(NVL(NPCP.VRSALFAMILIA,ESONP.VRSALFAMILIA),0)) AS VRSALFAMILIA,
                                  SUM(NVL(NVL(NPCP.VRSALFAMILIA13,ESONP.VRSALFAMILIA13),0)) AS VRSALFAMILIA13,
                                  SUM(NVL(NVL(NPCP.VRVALORMATERMENSAL,ESONP.VRVALORMATERMENSAL),0)) AS VRVALORMATERMENSAL,
                                  SUM(NVL(NVL(NPCP.VRVALORMATER13,ESONP.VRVALORMATER13),0)) AS VRVALORMATER13,
                                  EHL.CDCNPJESTRUT
                              FROM ESO_NAOPERIODICO ESONP
                              JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                                      AND NPCP.NRENVIO = ESONP.NRENVIO
                              LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = ESONP.NRORG
                                            AND EHL.NRESTRUTURAM = ESONP.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = ( SELECT DTMESCOMPETENC FROM(SELECT DTMESCOMPETENC FROM ESTRUTURAH
                                                                       WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                         AND NRORG        = EHL.NRORG
                                                                         AND NRESTRUTURAM = EHL.NRESTRUTURAM 
                                                                         ORDER BY DTMESCOMPETENC)WHERE ROWNUM = 1)
                              WHERE ESONP.NRORG = :P_NRORG
                              AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                              AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                              AND ESONP.IDSTATUS IN('C','A', 'M')
                              AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                              GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM, ESONP.NRESTRUTURAM, ESONP.NRTABELA, EHL.CDCNPJESTRUT, NPCP.CDMATRICULA
                            )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                                  AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                                  AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                                  AND ESONP.NRTABELA = RES.NRTABELA
                                  AND ESONP.NRVINCULOM = RES.NRVINCULOM
                                  AND (ESONP.CDMATRICULA = RES.MATRICULA OR ESONP.CDMATRICULA IS NULL)
                                  AND ESONP.DTMESCOMPETENC = RES.DTRESCISAOVINC
                                                    
                LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                                  ESOPE.NRTPAMBIENTE,
                                  ESOPE.NRCHAVE,
                                  ESOPE.NRESTRUTURAM,
                                  ESOPE.NRTABELA,
                                  PECP.CDMATRICULA,
                                  SUM(NVL(NVL(PECP.VRDESCONTADO,ESOPE.VRDESCONTADO),0)) AS VRDESCONTADO,
                                  SUM(NVL(NVL(PECP.VRCALCULADO,ESOPE.VRCALCULADO),0)) AS VRCALCULADO,
                                  SUM(NVL(NVL(PECP.VRBASE13,ESOPE.VRBASE13),0)) AS VRBASE13,
                                  SUM(NVL(NVL(PECP.VRBASEMENSAL,ESOPE.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                                  SUM(NVL(NVL(PECP.VRSALFAMILIA,ESOPE.VRSALFAMILIA),0)) AS VRSALFAMILIA,
                                  SUM(NVL(NVL(PECP.VRSALFAMILIA13,ESOPE.VRSALFAMILIA13),0)) AS VRSALFAMILIA13,
                                  SUM(NVL(NVL(PECP.VRVALORMATERMENSAL,ESOPE.VRVALORMATERMENSAL),0)) AS VRVALORMATERMENSAL,
                                  SUM(NVL(NVL(PECP.VRVALORMATER13,ESOPE.VRVALORMATER13),0)) AS VRVALORMATER13,
                                  EHL.CDCNPJESTRUT
                                
                              FROM ESO_PERIODICO ESOPE
                              JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                                      AND PECP.NRENVIO = ESOPE.NRENVIO
                              LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = ESOPE.NRORG
                                            AND EHL.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = (SELECT DTMESCOMPETENC FROM( SELECT DTMESCOMPETENC FROM ESTRUTURAH
                                                                       WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                         AND NRORG        = EHL.NRORG
                                                                         AND NRESTRUTURAM = EHL.NRESTRUTURAM
                                                                         ORDER BY DTMESCOMPETENC)WHERE ROWNUM = 1)
                              WHERE ESOPE.NRORG = :P_NRORG
                              AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                              AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                              AND ESOPE.IDSTATUS IN('C','A','M')
                              AND ESOPE.NMEVENTO = 'S-1200'
                              
                              GROUP BY ESOPE.DTMESCOMPETENC,ESOPE.NRTPAMBIENTE,ESOPE.NRESTRUTURAM, ESOPE.NRCHAVE, ESOPE.NRTABELA, EHL.CDCNPJESTRUT, PECP.CDMATRICULA
                            )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                                  AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                                  AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                                  AND ESOPE.NRCHAVE = RES.NRPESSOA
                                  AND (ESOPE.CDMATRICULA = RES.MATRICULA OR ESOPE.CDMATRICULA IS NULL)
                                  AND ESOPE.NRTABELA = RES.NRTABELA
                                  
                GROUP BY 
                  RES.NRORG, RES.NRPESSOA, RES.NRLEGAL,
                  RES.RAZAOLEGAL,
                  RES.CNPJLEGAL,
                  RES.INTLEGAL,
                  RES.BASE,
                  RES.INSS,
                  RES.MATERNIDADE,
                  RES.FAMILIA
                  ) PRI
        JOIN (SELECT '01' CODIGO, 'Base de Cálculo da Contribuição Previdenciária Normal' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '02' CODIGO, 'Valor Total da Contribuição Previdenciária dos Segurados' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '03' CODIGO, 'Valor Total do Salário Família' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '04' CODIGO, 'Valor Total do Salário Maternidade' DESCRICAO FROM DUAL) TAB ON 1=1
      GROUP BY NRLEGAL, RAZAOLEGAL, CNPJLEGAL, INTLEGAL, CNPJRAIZ, TAB.CODIGO, TAB.DESCRICAO)
ORDER BY CNPJRAIZ, CNPJLEGAL, CODIGO
    ";
    
    static $queryInformacoesSobreBasesCalculo = "
 /*queryInformacoesSobreBasesCalculo*/
 SELECT * FROM ( SELECT NRVINCULOM, NMVINCULOM, NRCPFPESSOA,
      NRLEGAL,
      RAZAOLEGAL,
      ('('||NRLEGAL||') '||RAZAOLEGAL||' '||CNPJLEGAL) ESTABELECIMENTO,
      CNPJLEGAL,
      PRI.CDFPAS,
      PRI.CDTERCEIRO,
      CNPJRAIZ,
      PRI.VRBASE_ESO BASE, 
      PRI.VRCALCULADO_ESO INSS, 
      PRI.VRMATERNIDADE_ESO MATERNIDADE,
      PRI.VRFAMILIA_ESO FAMILIA,
      PRI.NRESTRUTLOTACAO,
      (PRI.VRBASE_ESO * PRI.VRPERCEMPRESA / 100) VRFPAS,
      (PRI.VRBASE_ESO * PRI.VRFAP * PRI.VRALIQRAT / 100) VRRAT,
      (PRI.VRBASE_ESO * PRI.VRPERCTERCEIROS / 100) VRTERCEIROS,
      ( '('||PRI.NRESTRUTLOTACAO||') '||'FPAS '||PRI.CDFPAS||' '||'Terceiros '||PRI.CDTERCEIRO ) LOTACAO,
      PRI.CDESOCIAL CDCATEGESOC,
      (PRI.CDESOCIAL || ' - '|| PRI.DSCATEGESOC) DSCATEGESOC
    FROM (SELECT VM.NRVINCULOM,
                PE.NRCPFPESSOA,
                VM.NMVINCULOM,
                VH.NRESTRUTLEGAL NRLEGAL,
                EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                EHL.CDCNPJESTRUT   CNPJLEGAL,
                SUM(NVL(NPCP.VRDESCONTADO,NVL(ESONP.VRDESCONTADO,0)) + NVL(PECP.VRDESCONTADO,NVL(ESOPE.VRDESCONTADO,0))) VRDESC_ESO,
                SUM(NVL(NPCP.VRCALCULADO,NVL(ESONP.VRCALCULADO,0)) + NVL(PECP.VRCALCULADO,NVL(ESOPE.VRCALCULADO,0))) VRCALCULADO_ESO,
                SUM(NVL(NPCP.VRBASE13,NVL(ESONP.VRBASE13,0)) + NVL(PECP.VRBASE13,NVL(ESOPE.VRBASE13,0)) + NVL(NPCP.VRBASEMENSAL,NVL(ESONP.VRBASEMENSAL,0)) + NVL(PECP.VRBASEMENSAL,NVL(ESOPE.VRBASEMENSAL,0))) VRBASE_ESO,
                SUM(NVL(NPCP.VRVALORMATER13,NVL(ESONP.VRVALORMATER13,0)) + NVL(PECP.VRVALORMATER13,NVL(ESOPE.VRVALORMATER13,0)) + NVL(NPCP.VRVALORMATERMENSAL,NVL(ESONP.VRVALORMATERMENSAL,0)) + NVL(PECP.VRVALORMATERMENSAL,NVL(ESOPE.VRVALORMATERMENSAL,0))) VRMATERNIDADE_ESO,
                SUM(NVL(NPCP.VRSALFAMILIA13,NVL(ESONP.VRSALFAMILIA13,0)) + NVL(PECP.VRSALFAMILIA13,NVL(ESOPE.VRSALFAMILIA13,0)) + NVL(NPCP.VRSALFAMILIA,NVL(ESONP.VRSALFAMILIA,0)) + NVL(PECP.VRSALFAMILIA,NVL(ESOPE.VRSALFAMILIA,0))) VRFAMILIA_ESO,
                NVL(ESOPE.DTMESCOMPETENC, ESONP.DTMESCOMPETENC) PERIODO,
                SUBSTR(EHL.CDCNPJESTRUT, 0,8) CNPJRAIZ,
                NVL(ESOPE.NRENVIO,ESONP.NRENVIO) NRENVIO,
                NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO) NRESTRUTLOTACAO,
                NVL(LOT.CDFPAS,EHL.CDFPAS) CDFPAS,
                NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO) CDTERCEIRO,
                NVL(LOT.VRFAP,EHL.VRFAP) VRFAP,
                NVL(LOT.CDCNAE,EHL.CDCNAE) CDCNAE,
                CF.VRALIQRAT,
                PER.VRPERCEMPRESA,
                PER.VRPERCTERCEIROS,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL
            FROM GPE_VINCULOM VM
            JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                AND VH.NRVINCULOM = VM.NRVINCULOM
                                AND VH.DTMESCOMPETENC = ( SELECT *
                                                          FROM ( SELECT DTMESCOMPETENC
                                                                 FROM GPE_VINCULOH
                                                                 WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                   AND NRORG      = VH.NRORG
                                                                   AND NRVINCULOM = VH.NRVINCULOM
                                                                 ORDER BY DTMESCOMPETENC DESC )
                                                           WHERE ROWNUM = 1 )
            JOIN GPE_PESSOAH PE ON PE.NRPESSOA = VM.NRPESSOA 
                              AND PE.NRORG = VM.NRORG 
                              AND PE.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH 
                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                          AND NRORG = PE.NRORG
                                                          AND NRPESSOA = PE.NRPESSOA)
            /*ESTRUTURA LEGAL*/
            JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                    AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
            LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                    AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                    AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                              WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                AND NRORG        = VH.NRORG
                                                                AND NRESTRUTURAM = EML.NRESTRUTURAM )
                                                                   
            JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                                  AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
            LEFT JOIN ESO_NAOPERIODICO ESONP ON ESONP.NRORG = VM.NRORG
                                            AND TRUNC(ESONP.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                            AND ESONP.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                            AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                                            AND ESONP.IDSTATUS IN('C','A','M')
                                            AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                                            AND ESONP.NRVINCULOM = VM.NRVINCULOM
                                            AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
            LEFT JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                            AND NPCP.NRENVIO = ESONP.NRENVIO                                   
            LEFT JOIN ESO_PERIODICO ESOPE ON ESOPE.NRORG = VM.NRORG
                                         AND TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                         AND ESOPE.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                         AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                                         AND ESOPE.IDSTATUS IN('C','A','M')
                                         AND ESOPE.NMEVENTO IN ('S-1200')
                                         AND ESOPE.NRCHAVE = VM.NRPESSOA
                                         AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
            LEFT JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                         AND PECP.NRENVIO = ESOPE.NRENVIO
                                
            LEFT JOIN ESTRUTURAH LOT ON LOT.NRORG        = NVL(ESOPE.NRORG, ESONP.NRORG)
                                    AND LOT.NRESTRUTURAM = NVL(ESOPE.NRESTRUTLOTACAO, ESONP.NRESTRUTLOTACAO)
                                    AND LOT.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                              WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                AND NRORG        = LOT.NRORG
                                                                AND NRESTRUTURAM = LOT.NRESTRUTURAM )
            LEFT JOIN CNAEFISCAL CF ON CF.CDCNAE = NVL(LOT.CDCNAE,EHL.CDCNAE)
            LEFT JOIN (SELECT PEM.NRORG, PEM.NRESTRUTURAM, MAX(DECODE(ITG.NREVENTOM,3590,ITG.VRPERCENT,0)) VRPERCEMPRESA, MAX(DECODE(ITG.NREVENTOM,3870,ITG.VRPERCENT,0)) VRPERCTERCEIROS
                        FROM GPE_PARAMESTRUTM PEM
                        JOIN GPE_PARAMESTRUTH PEH ON PEH.NRORG = PEM.NRORG
                                                  AND PEH.NRPARAMESTRUTM = PEM.NRPARAMESTRUTM
                                                  AND PEH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM GPE_PARAMESTRUTH H1
                                                                              WHERE H1.DTMESCOMPETENC <= :P_COMPETENCIA
                                                                                AND H1.NRORG = PEH.NRORG
                                                                                AND H1.NRPARAMESTRUTM = PEH.NRPARAMESTRUTM )
                        JOIN FPA_PARAMFOLHAM PFM ON PFM.NRORG = PEH.NRORG
                                                AND PFM.NRPARAMFOLHAM = PEH.NRPARAMFOLHAM
                        JOIN FPA_PARAMFOLHAH PFH ON PFH.NRORG = PFM.NRORG
                                                AND PFH.NRPARAMFOLHAM = PFM.NRPARAMFOLHAM
                                                AND PFH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM FPA_PARAMFOLHAH H1
                                                                            WHERE H1.DTMESCOMPETENC <= :P_COMPETENCIA
                                                                              AND H1.NRORG = PFH.NRORG
                                                                              AND H1.NRPARAMFOLHAM = PFH.NRPARAMFOLHAM )
                        JOIN FPA_GRPINCIDE GRI ON GRI.NRORG = PFH.NRORG
                                              AND GRI.NRGRPINCIDE = PFH.NRGRPINCIDE
                        JOIN FPA_GRPITEM ITG ON ITG.NRORG = GRI.NRORG
                                            AND ITG.NRGRPINCIDE = GRI.NRGRPINCIDE
                        WHERE PEM.NRORG = :P_NRORG
                        GROUP BY PEM.NRORG, PEM.NRESTRUTURAM) PER ON PER.NRORG = NVL(LOT.NRORG, EHL.NRORG)
                                                                AND PER.NRESTRUTURAM = NVL(LOT.NRESTRUTURAM, EHL.NRESTRUTURAM)
            /*CATEGORIA*/
            JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
            JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
            /**/
            WHERE VM.NRORG = :P_NRORG
              AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
              AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
              AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL )
              AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
            GROUP BY VM.NRVINCULOM,
                PE.NRCPFPESSOA,
                VM.NMVINCULOM,
                VH.NRESTRUTLEGAL,
                EHL.NMRAZSOCESTRUT,
                EHL.CDCNPJESTRUT,
                NVL(ESOPE.DTMESCOMPETENC,ESONP.DTMESCOMPETENC),
                SUBSTR(EHL.CDCNPJESTRUT, 0,8),
                NVL(ESOPE.NRENVIO,ESONP.NRENVIO),
                NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO),
                NVL(LOT.CDFPAS,EHL.CDFPAS),
                NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO),
                NVL(LOT.VRFAP,EHL.VRFAP),
                NVL(LOT.CDCNAE,EHL.CDCNAE),
                CF.VRALIQRAT,
                PER.VRPERCEMPRESA,
                PER.VRPERCTERCEIROS,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL
              ) PRI
    GROUP BY NRVINCULOM, NMVINCULOM, NRCPFPESSOA, NRLEGAL, RAZAOLEGAL, CNPJLEGAL, PRI.CDFPAS, PRI.CDTERCEIRO, CNPJRAIZ, PRI.VRBASE_ESO, PRI.VRCALCULADO_ESO, PRI.VRMATERNIDADE_ESO, PRI.VRFAMILIA_ESO,
            PRI.NRESTRUTLOTACAO, PRI.VRFAP, PRI.VRALIQRAT, PRI.VRPERCEMPRESA, PRI.VRPERCTERCEIROS, PRI.DSCATEGESOC, PRI.CDESOCIAL)
  ORDER BY CNPJRAIZ, CNPJLEGAL, NMVINCULOM, DSCATEGESOC";
}
