<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class PreFechamentoFgtsRepository {
    
    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->conferenciaFgts = new ConferenciaFgts($entityManager);
        $this->informacoesSinteticasFgts = new InformacoesSinteticasFgts($entityManager);
        $this->informacoesSobreBasesCalculoFgts = new InformacoesSobreBasesCalculoFgts($entityManager);
    }
        
    public function getConferenciaFgts($parameters) {
        return $this->conferenciaFgts->getConferenciaFgts($parameters);
    }
    
    public function getEventosApuradosFgts($parameters) {
        return $this->conferenciaFgts->getEventosApurados($parameters);
    }
    
    public function getInformacoesSinteticasFgts($parameters) {
        return $this->informacoesSinteticasFgts->getInformacoesSinteticasFgts($parameters);
    }
    
    public function getInformacoesSobreBasesCalculoFgts($parameters) {
        return $this->informacoesSobreBasesCalculoFgts->getInformacoesSobreBasesCalculoFgts($parameters);
    }
}

class ConferenciaFgts {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getConferenciaFgts($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$conferenciaFgts);
        $sql->execute(
            array(
                'P_NRORG'          => $parameters['NRORG'],
                'P_MODALIDADECAL'  => 1,
                'P_COMPETENCIA'    => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL'  => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'      => '',
                'P_NRTABELA'       => $parameters['NRTABELA'],
                'P_IDDIFERENCA'   => $parameters['IDDIFERENCA'],
            )
        );
        return $sql->fetchAll();
    }
    
    public function getEventosApurados($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryEventosApuradosFgts);
        $sql->execute(
            array( 
                'P_NRORG'             => $parameters['NRORG'],
                'P_COMPETENCIA'       => $parameters['COMPETENCIA'],
                'P_NRVINCULOM'        => $parameters['NRVINCULOM'],
                'P_MODALIDADECAL'     => $parameters['MODALIDADECALCULO'],
                'P_NRTABELA'          => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSinteticasFgts {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSinteticasFgts($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$informacoesSinteticasFgts);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_MODALIDADECAL' => 1,
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSobreBasesCalculoFgts {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSobreBasesCalculoFgts($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$informacoesSobreBasesCalculoFgts);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class Queries {
    
    static $conferenciaFgts = "
/*conferenciaFgts_cte*/
WITH
ULT_COMP_PESS AS (
    SELECT 
        NRORG, 
        NRPESSOA, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM GPE_PESSOAH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_COMPETENCIA
    GROUP BY NRORG, NRPESSOA
),
ULT_COMP_VINC AS (
    SELECT 
        NRORG, 
        NRVINCULOM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM GPE_VINCULOH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_COMPETENCIA
    GROUP BY NRORG, NRVINCULOM
),
ULT_COMP_ESTRUT AS (
    SELECT 
        NRORG, 
        NRESTRUTURAM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM ESTRUTURAH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_COMPETENCIA
    GROUP BY NRORG, NRESTRUTURAM
),
VINCULOS AS (
    SELECT
        VM.NRORG, 
        VM.NRPESSOA,
        VM.NRVINCULOM,
        VM.DTRESCISAOVINC,
        NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM) AS MATRICULA,
        VM.NMVINCULOM,
        VM.NRTIPOVINCULOM,
        VH.NRESTRUTLEGAL AS NRLEGAL,
        VH.NRESTRUTGEREN AS NRGEREN,
        EHL.NMRAZSOCESTRUT AS RAZAOLEGAL,
        EHL.CDCNPJESTRUT AS CNPJLEGAL,
        CATEGTRAB.DSCATEGESOC,
        CATEGTRAB.CDESOCIAL,
        EP.NRTPAMBIENTE
    FROM GPE_VINCULOM VM
    JOIN ULT_COMP_VINC UCV ON UCV.NRORG = VM.NRORG
                          AND UCV.NRVINCULOM = VM.NRVINCULOM
    JOIN GPE_VINCULOH VH ON VH.NRORG = UCV.NRORG
                        AND VH.NRVINCULOM = UCV.NRVINCULOM
                        AND VH.DTMESCOMPETENC = UCV.DTMESCOMPETENC
    JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = VH.NRORG
                            AND UCE.NRESTRUTURAM = VH.NRESTRUTLEGAL
    JOIN ESTRUTURAH EHL ON EHL.NRORG = UCE.NRORG
                       AND EHL.NRESTRUTURAM = UCE.NRESTRUTURAM
                       AND EHL.DTMESCOMPETENC = UCE.DTMESCOMPETENC
    JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
    JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
    JOIN ESO_PARAMETRO EP ON EP.NRORG = EHL.NRORG
                         AND EP.NRESTRUTURAM = EHL.NRESTRUTURAM
    WHERE VM.NRORG = :P_NRORG
      AND (VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA))
      AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL)
      AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
      AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
)
SELECT * FROM (
    SELECT
        RES.NRVINCULOM,
          RES.DTRESCISAOVINC,
          RES.MATRICULA,
          PH.NRCPFPESSOA,
          PH.NRCPFPESSOA||' - '||RES.NMVINCULOM PESSOA,
          RES.NMVINCULOM,
          RES.NRLEGAL,
          RES.NRGEREN,
          RES.RAZAOLEGAL,
          RES.CNPJLEGAL,
          NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
          NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), CAL.NRTABELA) NRTABELA,
          NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO) NMEVENTO,
          :P_COMPETENCIA PERIODO,
          SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
          RES.CDESOCIAL CDCATEGESOC,
          (RES.CDESOCIAL || ' - ' || RES.DSCATEGESOC) DSCATEGESOC,
          CAL.BASE BASE_FGTS,
          CAL.FGTS DEPOSITO_FGTS,
          SUM(NVL(ESONP.VRBASEFGTSMENSAL,0) + NVL(ESOPE.VRBASEFGTSMENSAL,0) + NVL(ESONP.VRBASEFGTS13,0) + NVL(ESOPE.VRBASEFGTS13,0)) BASE_FGTS_ESOCIAL,
          SUM(NVL(ESONP.VRDEPOSITOFGTS,0) + NVL(ESOPE.VRDEPOSITOFGTS,0) + NVL(ESONP.VRDEPOSITOFGTS13,0) + NVL(ESOPE.VRDEPOSITOFGTS13,0)) DEPOSITO_FGTS_ESOCIAL,
          CAL.BASE - SUM(NVL(ESONP.VRBASEFGTSMENSAL,0) + NVL(ESOPE.VRBASEFGTSMENSAL,0) + NVL(ESONP.VRBASEFGTS13,0) + NVL(ESOPE.VRBASEFGTS13,0)) DIFERENCA_BASE,
          CAL.FGTS - SUM(NVL(ESONP.VRDEPOSITOFGTS,0) + NVL(ESOPE.VRDEPOSITOFGTS,0) + NVL(ESONP.VRDEPOSITOFGTS13,0) + NVL(ESOPE.VRDEPOSITOFGTS13,0)) DIFERENCA_DEPOSITO
    FROM VINCULOS RES
    JOIN ULT_COMP_PESS UCP ON UCP.NRORG = RES.NRORG
                          AND UCP.NRPESSOA = RES.NRPESSOA
    JOIN GPE_PESSOAH PH ON PH.NRORG = UCP.NRORG
                       AND PH.NRPESSOA = UCP.NRPESSOA
                       AND PH.DTMESCOMPETENC = UCP.DTMESCOMPETENC
    LEFT JOIN (SELECT CF.DTOCORRENCIA,
                        CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                             WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                        END NRTABELA,
                        ICF.NRVINCULOM,
                        SUM(CASE WHEN ICF.NREVENTOM IN (3060, 3180, 3210, 3120) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                        SUM(CASE WHEN ICF.NREVENTOM IN (2010, 2050, 2080, 2020) THEN ICF.VREVENTOFOLHA ELSE 0 END) FGTS
                   FROM FPA_CALCULOFOLHA CF
                   JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG = CF.NRORG
                                            AND ICF.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                                            AND ICF.NREVENTOM IN (3060, 2010, 3180, 2050, 3210, 2080, 3120, 2020)
                                            AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                         WHERE IC.NRORG = ICF.NRORG
                                                           AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                           AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                           AND IC.NREVENTOM IN (3030, 3050))
                  WHERE CF.NRORG = :P_NRORG
                    AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                         (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                         (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                    AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                    AND CF.DTOCORRENCIA = :P_COMPETENCIA
                  GROUP BY CF.DTOCORRENCIA,
                           CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                             WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                           END,
                           ICF.NRVINCULOM
            ) CAL ON CAL.NRVINCULOM = RES.NRVINCULOM
    LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                    ESONP.NRTPAMBIENTE,
                    ESONP.NRVINCULOM,
                    NPFGTS.CDMATRICULA,
                    ESONP.NRESTRUTURAM,
                    ESONP.NRORG,
                    ESONP.IDSTATUS,
                    NVL(ESONP.NRTABELA, 1) NRTABELA,
                    ESONP.NMEVENTO,
                    SUM(NVL(NPFGTS.VRBASEFGTSMENSAL,0)) AS VRBASEFGTSMENSAL,
                    SUM(NVL(NPFGTS.VRBASEFGTS13,0)) AS VRBASEFGTS13,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS, 0)) AS VRDEPOSITOFGTS,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13,
                    ESONP.NRENVIO,
                    EHPN.CDCNPJESTRUT
                FROM ESO_NAOPERIODICO ESONP 
                JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = ESONP.NRORG
                                        AND UCE.NRESTRUTURAM = ESONP.NRESTRUTURAM
                JOIN ESTRUTURAH EHPN ON EHPN.NRORG = UCE.NRORG
                                    AND EHPN.NRESTRUTURAM = UCE.NRESTRUTURAM
                                    AND EHPN.DTMESCOMPETENC = UCE.DTMESCOMPETENC
                JOIN ESO_NAOPERIODFGTS NPFGTS ON NPFGTS.NRORG = ESONP.NRORG
                                        AND NPFGTS.NRENVIO = ESONP.NRENVIO
                WHERE ESONP.NRORG = :P_NRORG
                AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                AND ESONP.IDSTATUS IN('C','A')
                AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM, NPFGTS.CDMATRICULA, ESONP.NRENVIO, EHPN.CDCNPJESTRUT , ESONP.NRESTRUTURAM , ESONP.NRORG, ESONP.IDSTATUS, ESONP.NRTABELA, ESONP.NMEVENTO
            ) ESONP ON ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESONP.NRVINCULOM = RES.NRVINCULOM
                   AND (ESONP.CDMATRICULA = RES.MATRICULA OR ESONP.CDMATRICULA IS NULL)
                   AND ESONP.DTMESCOMPETENC = RES.DTRESCISAOVINC
                   AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ((TRUNC(ESONP.DTMESCOMPETENC, 'MM') = CAL.DTOCORRENCIA AND ESONP.NRTABELA = CAL.NRTABELA) OR CAL.DTOCORRENCIA IS NULL)
    LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                    ESOPE.NRTPAMBIENTE,
                    ESOPE.NRCHAVE,
                    PEFGTS.CDMATRICULA,
                    ESOPE.NRESTRUTURAM,
                    ESOPE.NRORG,
                    ESOPE.IDSTATUS,
                    ESOPE.NRTABELA,
                    ESOPE.NMEVENTO,
                    SUM(NVL(PEFGTS.VRBASEFGTSMENSAL,0)) AS VRBASEFGTSMENSAL,
                    SUM(NVL(PEFGTS.VRBASEFGTS13,0)) AS VRBASEFGTS13,
                    SUM(NVL(PEFGTS.VRDEPOSITOFGTS, 0)) AS VRDEPOSITOFGTS,
                    SUM(NVL(PEFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13,
                    ESOPE.NRENVIO,
                    EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE   
                JOIN ULT_COMP_ESTRUT UCE ON UCE.NRORG = ESOPE.NRORG
                                        AND UCE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG = UCE.NRORG
                                    AND EHPE.NRESTRUTURAM = UCE.NRESTRUTURAM
                                    AND EHPE.DTMESCOMPETENC = UCE.DTMESCOMPETENC
                JOIN ESO_PERIODFGTS PEFGTS ON PEFGTS.NRORG = ESOPE.NRORG
                                        AND PEFGTS.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESOPE.NMEVENTO = 'S-1200'
                GROUP BY ESOPE.DTMESCOMPETENC,ESOPE.NRTPAMBIENTE,ESOPE.NRCHAVE, PEFGTS.CDMATRICULA, ESOPE.NRENVIO, EHPE.CDCNPJESTRUT ,ESOPE.NRESTRUTURAM, ESOPE.NRORG, ESOPE.IDSTATUS, ESOPE.NRTABELA, ESOPE.NMEVENTO
            ) ESOPE ON ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND (ESOPE.CDMATRICULA = RES.MATRICULA OR ESOPE.CDMATRICULA IS NULL)
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ((TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = CAL.DTOCORRENCIA AND ESOPE.NRTABELA = CAL.NRTABELA) OR CAL.DTOCORRENCIA IS NULL)
    GROUP BY RES.NRVINCULOM,
            RES.DTRESCISAOVINC,
            RES.MATRICULA,
            PH.NRCPFPESSOA,
            RES.NMVINCULOM,
            RES.NRLEGAL,
            RES.NRGEREN,
            RES.RAZAOLEGAL,
            RES.CNPJLEGAL,
            NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS),
            NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), CAL.NRTABELA),
            NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO),
            RES.CDESOCIAL,
            (RES.CDESOCIAL || ' - ' || RES.DSCATEGESOC),
            CAL.BASE,
            CAL.FGTS
    )
WHERE ( BASE_FGTS IS NOT NULL OR NMEVENTO IS NOT NULL )
  AND ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_DEPOSITO) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_DEPOSITO) > 0.05 ) )
      )";
    
    static $conferenciaFgts_old = "
      /*conferenciaFgts*/
      SELECT * FROM ( 
        SELECT RES.NRVINCULOM,
              RES.DTRESCISAOVINC,
              RES.MATRICULA,
              PE.NRCPFPESSOA,
              PE.NRCPFPESSOA||' - '||RES.NMVINCULOM PESSOA,
              RES.NMVINCULOM,
              RES.NRLEGAL,
              RES.NRGEREN,
              RES.RAZAOLEGAL,
              RES.CNPJLEGAL,
              RES.INTLEGAL,
              RES.RAZAOGEREN,
              RES.CNPJGEREN,
              RES.INTGEREN,
              NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
              NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), RES.NRTABELA) NRTABELA,
              NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO) NMEVENTO,
              :P_COMPETENCIA PERIODO,
              SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
              RES.CDESOCIAL CDCATEGESOC,
              (RES.CDESOCIAL || ' - ' || RES.DSCATEGESOC) DSCATEGESOC,
              RES.BASE BASE_FGTS,
              RES.FGTS DEPOSITO_FGTS,
              SUM(NVL(ESONP.VRBASEFGTSMENSAL,0) + NVL(ESOPE.VRBASEFGTSMENSAL,0) + NVL(ESONP.VRBASEFGTS13,0) + NVL(ESOPE.VRBASEFGTS13,0)) BASE_FGTS_ESOCIAL,
              SUM(NVL(ESONP.VRDEPOSITOFGTS,0) + NVL(ESOPE.VRDEPOSITOFGTS,0) + NVL(ESONP.VRDEPOSITOFGTS13,0) + NVL(ESOPE.VRDEPOSITOFGTS13,0)) DEPOSITO_FGTS_ESOCIAL,
              RES.BASE - SUM(NVL(ESONP.VRBASEFGTSMENSAL,0) + NVL(ESOPE.VRBASEFGTSMENSAL,0) + NVL(ESONP.VRBASEFGTS13,0) + NVL(ESOPE.VRBASEFGTS13,0)) DIFERENCA_BASE,
              RES.FGTS - SUM(NVL(ESONP.VRDEPOSITOFGTS,0) + NVL(ESOPE.VRDEPOSITOFGTS,0) + NVL(ESONP.VRDEPOSITOFGTS13,0) + NVL(ESOPE.VRDEPOSITOFGTS13,0)) DIFERENCA_DEPOSITO
          FROM (SELECT VM.NRORG, VM.NRPESSOA,
                      VM.NRVINCULOM,
                      VM.DTRESCISAOVINC,
                      VM.CDMATRICULA     MATRICULA,
                      VM.NMVINCULOM,
                      VM.NRTIPOVINCULOM,
                      SUM(CASE WHEN ICF.NREVENTOM IN (3060, 3180, 3210, 3120) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                      SUM(CASE WHEN ICF.NREVENTOM IN (2010, 2050, 2080, 2020) THEN ICF.VREVENTOFOLHA ELSE 0 END) FGTS,
                      CF.DTOCORRENCIA,
                      CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                           WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                      END NRTABELA,
                      VH.NRESTRUTLEGAL   NRLEGAL,
                      VH.NRESTRUTGEREN   NRGEREN,
                      EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                      EHL.CDCNPJESTRUT   CNPJLEGAL,
                      EML.CDINTESTRUTURA INTLEGAL,
                      EHG.NMRAZSOCESTRUT RAZAOGEREN,
                      EHG.CDCNPJESTRUT   CNPJGEREN,
                      EMG.CDINTESTRUTURA INTGEREN,
                      CATEGTRAB.DSCATEGESOC, 
                      CATEGTRAB.CDESOCIAL, 
                      EP.NRTPAMBIENTE
                  FROM GPE_VINCULOM VM
                  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                                      AND VH.NRVINCULOM = VM.NRVINCULOM
                                      AND VH.DTMESCOMPETENC = ( SELECT * FROM(SELECT GPE_VINCULOH.DTMESCOMPETENC 
                                                                  FROM GPE_VINCULOH
                                                                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                  AND NRORG      = VM.NRORG
                                                                  AND NRVINCULOM = VM.NRVINCULOM 
                                                                  ORDER BY GPE_VINCULOH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  /*ESTRUTURA LEGAL*/
                  JOIN ESTRUTURAM EML ON EML.NRORG = VH.NRORG
                                    AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                  LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG = VH.NRORG
                                          AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                          AND EHL.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC 
                                                                      FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG = VH.NRORG
                                                                        AND NRESTRUTURAM = EML.NRESTRUTURAM 
                                                                        ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  /*ESTRUTURA GERENCIAL*/
                  JOIN ESTRUTURAM EMG ON EMG.NRORG = VH.NRORG
                                    AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
                  LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG = VH.NRORG
                                          AND EHG.NRESTRUTURAM = EMG.NRESTRUTURAM
                                          AND EHG.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC 
                                                                      FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = VH.NRORG
                                                                        AND NRESTRUTURAM = EMG.NRESTRUTURAM 
                                                                        ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  /*CÁLCULO DE FOLHA*/
                  JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG = VM.NRORG
                                          AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                          AND ICF.NREVENTOM IN (3060, 2010, 3180, 2050, 3210, 2080, 3120, 2020)
                                          AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                       WHERE IC.NRORG = ICF.NRORG
                                                         AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                         AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                         AND IC.NREVENTOM IN (3030, 3050))
                  JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = ICF.NRORG
                                          AND CF.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                          AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                                               (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                                               (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                          AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                          AND CF.DTOCORRENCIA = :P_COMPETENCIA
                  /*CATEGORIA*/
                  JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG 
                  JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC 
                  JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG 
                    AND EP.NRESTRUTURAM = EML.NRESTRUTURAM 
                  /**/
                WHERE VM.NRORG = :P_NRORG
                  AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                  AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                  AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                  AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM,
                  VM.DTRESCISAOVINC,
                  VM.CDMATRICULA,
                  VM.NMVINCULOM,
                  VM.NRTIPOVINCULOM,
                  /*ICF.NREVENTOM,*/
                  CF.DTOCORRENCIA,
                  CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1) THEN 1
                       WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 THEN 4
                  END,
                  VH.NRESTRUTLEGAL,
                  VH.NRESTRUTGEREN,
                  EHL.NMRAZSOCESTRUT,
                  EHL.CDCNPJESTRUT,
                  EML.CDINTESTRUTURA,
                  EHG.NMRAZSOCESTRUT,
                  EHG.CDCNPJESTRUT,
                  EMG.CDINTESTRUTURA,
                  CATEGTRAB.DSCATEGESOC,
                  CATEGTRAB.CDESOCIAL,
                  EP.NRTPAMBIENTE
                ) RES
        LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                    ESONP.NRTPAMBIENTE,
                    ESONP.NRVINCULOM,
                    ESONP.NRESTRUTURAM,
                    ESONP.NRORG,
                    ESONP.IDSTATUS,
                    NVL(ESONP.NRTABELA, 1) NRTABELA,
                    ESONP.NMEVENTO,
                    SUM(NVL(NPFGTS.VRBASEFGTSMENSAL,0)) AS VRBASEFGTSMENSAL,
                    SUM(NVL(NPFGTS.VRBASEFGTS13,0)) AS VRBASEFGTS13,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS, 0)) AS VRDEPOSITOFGTS,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13,
                    ESONP.NRENVIO,
                    EHPN.CDCNPJESTRUT
                FROM ESO_NAOPERIODICO ESONP 
                JOIN ESTRUTURAH EHPN ON EHPN.NRORG   = ESONP.NRORG
                                          AND EHPN.NRESTRUTURAM = ESONP.NRESTRUTURAM
                                          AND EHPN.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESONP.NRORG
                                                                      AND NRESTRUTURAM = EHPN.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                JOIN ESO_NAOPERIODFGTS NPFGTS ON NPFGTS.NRORG = ESONP.NRORG
                                        AND NPFGTS.NRENVIO = ESONP.NRENVIO
                WHERE ESONP.NRORG = :P_NRORG
                AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                AND ESONP.IDSTATUS IN('C','A')
                AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM,ESONP.NRENVIO, EHPN.CDCNPJESTRUT , ESONP.NRESTRUTURAM , ESONP.NRORG, ESONP.IDSTATUS, ESONP.NRTABELA, ESONP.NMEVENTO
            )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESONP.NRVINCULOM = RES.NRVINCULOM
                   AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ESONP.NRTABELA = RES.NRTABELA
                   
        LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                ESOPE.NRTPAMBIENTE,
                ESOPE.NRCHAVE,
                ESOPE.NRESTRUTURAM,
                ESOPE.NRORG,
                ESOPE.IDSTATUS,
                ESOPE.NRTABELA,
                ESOPE.NMEVENTO,
                SUM(NVL(PEFGTS.VRBASEFGTSMENSAL,0)) AS VRBASEFGTSMENSAL,
                SUM(NVL(PEFGTS.VRBASEFGTS13,0)) AS VRBASEFGTS13,
                SUM(NVL(PEFGTS.VRDEPOSITOFGTS, 0)) AS VRDEPOSITOFGTS,
                SUM(NVL(PEFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13,
                ESOPE.NRENVIO,
                EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE   
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG   = ESOPE.NRORG
                                          AND EHPE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                                          AND EHPE.DTMESCOMPETENC = ( SELECT * FROM (SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESOPE.NRORG
                                                                      AND NRESTRUTURAM = EHPE.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                JOIN ESO_PERIODFGTS PEFGTS ON PEFGTS.NRORG = ESOPE.NRORG
                                        AND PEFGTS.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESOPE.NMEVENTO = 'S-1200'
                GROUP BY ESOPE.DTMESCOMPETENC,ESOPE.NRTPAMBIENTE,ESOPE.NRCHAVE,ESOPE.NRENVIO, EHPE.CDCNPJESTRUT ,ESOPE.NRESTRUTURAM, ESOPE.NRORG, ESOPE.IDSTATUS, ESOPE.NRTABELA, ESOPE.NMEVENTO
            )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                   AND ESOPE.NRTABELA = RES.NRTABELA
        JOIN GPE_PESSOAH PE ON PE.NRPESSOA = RES.NRPESSOA 
                          AND PE.NRORG = RES.NRORG 
                          AND PE.DTMESCOMPETENC = ( SELECT * FROM (SELECT GPE_PESSOAH.DTMESCOMPETENC 
                                                      FROM GPE_PESSOAH 
                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                        AND NRORG = PE.NRORG
                                                        AND NRPESSOA = PE.NRPESSOA 
                                                        ORDER BY GPE_PESSOAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
      GROUP BY RES.NRVINCULOM,
                RES.DTRESCISAOVINC,
                RES.MATRICULA,
                PE.NRCPFPESSOA,
                RES.NMVINCULOM,
                RES.NRLEGAL,
                RES.NRGEREN,
                RES.RAZAOLEGAL,
                RES.CNPJLEGAL,
                RES.INTLEGAL,
                RES.RAZAOGEREN,
                RES.CNPJGEREN,
                RES.INTGEREN,
                NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS),
                NVL(NVL(ESOPE.NRTABELA, ESONP.NRTABELA), RES.NRTABELA),
                NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO),
                RES.CDESOCIAL,
                (RES.CDESOCIAL || ' - ' || RES.DSCATEGESOC),
                RES.BASE,
                RES.FGTS
      )
      WHERE ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_DEPOSITO) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_DEPOSITO) > 0.05 ) )
      )";
      
      static $queryEventosApuradosFgts = "
/*queryEventosApuradosFgts*/
SELECT
       CF.NRCALCULOFOLHA||' - '||TM.NMTIPOMOVIMENT||' - '||TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY')||' - Ocorrência:'||CF.NROCORRECAL PROCESSO,
       EH.NREVENTOM,
       EH.NMEVENTOH,
       TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY') PERIODO,
       TO_CHAR(ICF.DTOCORRENCIA, 'DD/MM/YYYY') DTOCORRENCIA,
       CF.NROCORRECAL,
       ICF.VREVENTOFOLHA,
       DECODE(EH.IDEVENTODEMONST,'S','3',DECODE(EM.IDTIPOEVENTO,'PROVENTO','1','DESCONTO','2','ENCARGO','3','TOTAL','3')) IDTPRUBRICA,
       RU.CDINCIDEFGTS,
       DECODE(EH.NRNATURUBR, NULL, 'Sem parametrização', FGTS.DSINCIDFGTS) INCIDEFGTS
  FROM FPA_ITECALCFOLHA ICF
  JOIN FPA_CALCULOFOLHA CF 
    ON CF.NRORG = ICF.NRORG
   AND CF.NRCALCULOFOLHA  = ICF.NRCALCULOFOLHA
   AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
         (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
         (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
   AND CF.NRTPMODALIDCAL  = :P_MODALIDADECAL
   AND CF.DTOCORRENCIA    = :P_COMPETENCIA
  JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  JOIN FPA_EVENTOM EM ON (EM.NREVENTOM = ICF.NREVENTOM)
  JOIN FPA_EVENTOH EH ON (EH.NREVENTOM = EM.NREVENTOM)
  JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NREVENTOM
          FROM FPA_EVENTOH 
         WHERE DTMESCOMPETENC <= :P_COMPETENCIA
         GROUP BY NREVENTOM) EHATUAL 
            ON ( EHATUAL.NREVENTOM = EH.NREVENTOM
           AND EHATUAL.DTMESCOMPETENC = EH.DTMESCOMPETENC)
  LEFT JOIN ESO_RUBRICA RU ON (RU.NRORG = ICF.NRORG OR RU.NRORG = 0)
                          AND RU.NREVENTOM = EM.NREVENTOM
                          AND RU.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  LEFT JOIN INCIDENCIAFGTS FGTS ON FGTS.CDESOCIAL = RU.CDINCIDEFGTS
 WHERE ICF.NRORG = :P_NRORG
   AND ICF.NRVINCULOM = :P_NRVINCULOM
    ";
    
    static $informacoesSinteticasFgts = "
      /*informacoesSinteticasFgts*/
      SELECT 
      * 
      FROM (
        SELECT 
            NRLEGAL,
            RAZAOLEGAL,
            ('('||NRLEGAL||') '||RAZAOLEGAL) ESTABELECIMENTO,
            CNPJLEGAL,
            INTLEGAL,
            CNPJRAIZ,
            SUM(DEPOSITO_FGTS) DEPOSITO_FGTS,
            SUM(DEPOSITO_FGTS_ESOCIAL) DEPOSITO_FGTS_ESOCIAL,
            SUM(DEPOSITO_FGTS_13) DEPOSITO_FGTS_13,
            SUM(DEPOSITO_FGTS_ESOCIAL_13) DEPOSITO_FGTS_ESOCIAL_13,
            /*SUM(FGTS_RESCISAO) FGTS_RESCISAO,
            SUM( (CASE WHEN DTRESCISAOVINC IS NOT NULL THEN DEPOSITO_FGTS_ESOCIAL ELSE 0 END) ) RESCISAO_ESOCIAL,*/
            SUM((DEPOSITO_FGTS + DEPOSITO_FGTS_13) - (DEPOSITO_FGTS_ESOCIAL + DEPOSITO_FGTS_ESOCIAL_13)) DIFERENCA_DEPOSITO
          FROM (
              SELECT RES.NRVINCULOM,
                    PE.NRCPFPESSOA,
                    RES.NMVINCULOM,
                    RES.NRLEGAL,
                    RES.RAZAOLEGAL,
                    RES.CNPJLEGAL,
                    RES.INTLEGAL,
                    NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
                    SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
                    SUM(RES.FGTS_MES) DEPOSITO_FGTS,
                    SUM(RES.FGTS_13) DEPOSITO_FGTS_13,
                    SUM(NVL(ESONP.VRDEPOSITOFGTS,0) + NVL(ESOPE.VRDEPOSITOFGTS,0)) DEPOSITO_FGTS_ESOCIAL,
                    SUM(NVL(ESONP.VRDEPOSITOFGTS13,0) + NVL(ESOPE.VRDEPOSITOFGTS13,0)) DEPOSITO_FGTS_ESOCIAL_13
                    /*SUM(RES.FGTS_RESCISAO) FGTS_RESCISAO*/
                FROM (SELECT VM.NRORG, VM.NRPESSOA,
                            VM.NRVINCULOM,
                            VM.NMVINCULOM,
                            CF.DTOCORRENCIA,
                            CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                                 WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                            END NRTABELA,
                            VH.NRESTRUTLEGAL   NRLEGAL,
                            EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                            EHL.CDCNPJESTRUT   CNPJLEGAL,
                            EML.CDINTESTRUTURA INTLEGAL,
                            EP.NRTPAMBIENTE,
                            SUM(CASE WHEN ICF.NREVENTOM IN (2010, 2050) THEN ICF.VREVENTOFOLHA ELSE 0 END) FGTS_MES,
                            SUM(CASE WHEN ICF.NREVENTOM IN (2020, 2080) THEN ICF.VREVENTOFOLHA ELSE 0 END) FGTS_13
                        FROM GPE_VINCULOM VM
                        JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                                            AND VH.NRVINCULOM = VM.NRVINCULOM
                                            AND VH.DTMESCOMPETENC = ( SELECT * FROM (SELECT GPE_VINCULOH.DTMESCOMPETENC 
                                                                        FROM GPE_VINCULOH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG      = VM.NRORG
                                                                        AND NRVINCULOM = VM.NRVINCULOM 
                                                                        ORDER BY GPE_VINCULOH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                        /*ESTRUTURA LEGAL*/
                        JOIN ESTRUTURAM EML ON EML.NRORG = VH.NRORG
                                          AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                        LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG = VH.NRORG
                                                AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                                AND EHL.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC 
                                                                            FROM ESTRUTURAH
                                                                            WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                              AND NRORG = VH.NRORG
                                                                              AND NRESTRUTURAM = EML.NRESTRUTURAM 
                                                                              ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                      /*CÁLCULO DE FOLHA*/
                      JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG = VM.NRORG
                                              AND ICF.NRVINCULOM = VM.NRVINCULOM
                                              AND ICF.NREVENTOM IN (2010, 2050, 2080, 2020)
                                              AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                           WHERE IC.NRORG = ICF.NRORG
                                                             AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                             AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                             AND IC.NREVENTOM IN (3030, 3050))
                      JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = ICF.NRORG
                                              AND CF.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                              AND (((CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL <> 1)) AND :P_NRTABELA = 1) OR
                                                   (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' AND CF.NROCORRECAL = 1 AND :P_NRTABELA = 4) OR
                                                   (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                              AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                              AND CF.DTOCORRENCIA = :P_COMPETENCIA
                      JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG 
                        AND EP.NRESTRUTURAM = EML.NRESTRUTURAM 
                      WHERE VM.NRORG = :P_NRORG
                        AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                        AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                        AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                        AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                      GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM,
                        VM.NMVINCULOM,
                        /*ICF.NREVENTOM,*/
                        CF.DTOCORRENCIA,
                        CASE WHEN CF.NRTIPOMOVIMENT IN (1,2,10,19) OR (CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') <> '12') THEN 1
                             WHEN CF.NRTIPOMOVIMENT = 4 AND TO_CHAR(CF.DTOCORRENCIA,'MM') = '12' THEN 4
                        END,
                        VH.NRESTRUTLEGAL,
                        EHL.NMRAZSOCESTRUT,
                        EHL.CDCNPJESTRUT,
                        EML.CDINTESTRUTURA,
                        EP.NRTPAMBIENTE
                      ) RES
          LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                    ESONP.NRTPAMBIENTE,
                    ESONP.NRVINCULOM,
                    NVL(ESONP.NRTABELA, 1) NRTABELA,
                    ESONP.IDSTATUS,
                    EHPN.CDCNPJESTRUT,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS,0)) AS VRDEPOSITOFGTS,
                    SUM(NVL(NPFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13
                  FROM ESO_NAOPERIODICO ESONP 
                  JOIN ESTRUTURAH EHPN ON EHPN.NRORG   = ESONP.NRORG
                                            AND EHPN.NRESTRUTURAM = ESONP.NRESTRUTURAM
                                            AND EHPN.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = ESONP.NRORG
                                                                        AND NRESTRUTURAM = EHPN.NRESTRUTURAM 
                                                                        ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  JOIN ESO_NAOPERIODFGTS NPFGTS ON NPFGTS.NRORG = ESONP.NRORG
                                          AND NPFGTS.NRENVIO = ESONP.NRENVIO
                  WHERE ESONP.NRORG = :P_NRORG
                  AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                  AND ESONP.IDSTATUS IN('C','A')
                  AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                  AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                  GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM, NVL(ESONP.NRTABELA, 1), ESONP.IDSTATUS, EHPN.CDCNPJESTRUT
                )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                     AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                     AND ESONP.NRVINCULOM = RES.NRVINCULOM
                     AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                     AND ESONP.NRTABELA = RES.NRTABELA
                   
          LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                            ESOPE.NRTPAMBIENTE,
                            ESOPE.NRCHAVE,
                            ESOPE.NRTABELA,
                            EHPE.CDCNPJESTRUT,
                            ESOPE.IDSTATUS,
                            SUM(NVL(PEFGTS.VRDEPOSITOFGTS,0)) AS VRDEPOSITOFGTS,
                            SUM(NVL(PEFGTS.VRDEPOSITOFGTS13,0)) AS VRDEPOSITOFGTS13
                    FROM ESO_PERIODICO ESOPE   
                    JOIN ESTRUTURAH EHPE ON EHPE.NRORG   = ESOPE.NRORG
                                              AND EHPE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                                              AND EHPE.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                          WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                          AND NRORG        = ESOPE.NRORG
                                                                          AND NRESTRUTURAM = EHPE.NRESTRUTURAM 
                                                                          ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                    JOIN ESO_PERIODFGTS PEFGTS ON PEFGTS.NRORG = ESOPE.NRORG
                                            AND PEFGTS.NRENVIO = ESOPE.NRENVIO
                    WHERE ESOPE.NRORG = :P_NRORG
                    AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                    AND ESOPE.IDSTATUS IN('C','A')
                    AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                    AND ESOPE.NMEVENTO = 'S-1200'
                    GROUP BY ESOPE.DTMESCOMPETENC, ESOPE.NRTPAMBIENTE, ESOPE.NRCHAVE, ESOPE.NRTABELA, EHPE.CDCNPJESTRUT, ESOPE.IDSTATUS
                  )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                       AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                       AND ESOPE.NRCHAVE = RES.NRPESSOA
                       AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                       AND ESOPE.NRTABELA = RES.NRTABELA
              JOIN GPE_PESSOAH PE ON PE.NRPESSOA = RES.NRPESSOA 
                                AND PE.NRORG = RES.NRORG 
                                AND PE.DTMESCOMPETENC = ( SELECT * FROM (SELECT GPE_PESSOAH.DTMESCOMPETENC 
                                                            FROM GPE_PESSOAH 
                                                            WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                              AND NRORG = PE.NRORG
                                                              AND NRPESSOA = PE.NRPESSOA 
                                                              ORDER BY GPE_PESSOAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
            GROUP BY RES.NRVINCULOM,
                    PE.NRCPFPESSOA,
                    RES.NMVINCULOM,
                    RES.NRLEGAL,
                    RES.RAZAOLEGAL,
                    RES.CNPJLEGAL,
                    RES.INTLEGAL,
                    NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS),
                    SUBSTR(RES.CNPJLEGAL, 0,8)
            )
    GROUP BY NRLEGAL, RAZAOLEGAL, CNPJLEGAL, INTLEGAL, CNPJRAIZ)
    ORDER BY CNPJRAIZ, CNPJLEGAL";
    
    static $informacoesSobreBasesCalculoFgts = "
      /*informacoesSobreBasesCalculoFgts*/
      SELECT * FROM ( 
        SELECT 
            NRVINCULOM,
            NMVINCULOM, 
            NRCPFPESSOA,
            NRLEGAL,
            RAZAOLEGAL,
            ('('||NRLEGAL||') '||RAZAOLEGAL||' '||CNPJLEGAL) ESTABELECIMENTO,
            CNPJLEGAL,
            PRI.CDTERCEIRO,
            CNPJRAIZ,
            PRI.VRBASEFGTSMENSAL BASE_ESOCIAL,
            PRI.VRBASEFGTS13 BASE_13_ESOCIAL,
            PRI.NRESTRUTLOTACAO,
            ( '('||PRI.NRESTRUTLOTACAO||') '||'FPAS '||PRI.CDFPAS||' '||'Terceiros '||PRI.CDTERCEIRO ) LOTACAO,
            (PRI.CDESOCIAL || ' - '|| PRI.DSCATEGESOC) DSCATEGESOC
          FROM (SELECT 
                    VM.NRVINCULOM,
                    PE.NRCPFPESSOA,
                    VM.NMVINCULOM,
                    VH.NRESTRUTLEGAL NRLEGAL,
                    EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                    EHL.CDCNPJESTRUT CNPJLEGAL,
                    SUBSTR(EHL.CDCNPJESTRUT, 0,8) CNPJRAIZ,
                    SUM(NVL(NPFGTS.VRBASEFGTSMENSAL,0) + NVL(PEFGTS.VRBASEFGTSMENSAL,0) ) VRBASEFGTSMENSAL,
                    SUM(NVL(NPFGTS.VRBASEFGTS13,0) + NVL(PEFGTS.VRBASEFGTS13,0) ) VRBASEFGTS13,
                    NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO) NRESTRUTLOTACAO,
                    NVL(LOT.CDFPAS,EHL.CDFPAS) CDFPAS,
                    NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO) CDTERCEIRO,
                    VM.DTRESCISAOVINC,
                    CATEGTRAB.DSCATEGESOC,
                    CATEGTRAB.CDESOCIAL
                  FROM GPE_VINCULOM VM
                  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                                      AND VH.NRVINCULOM = VM.NRVINCULOM
                                      AND VH.DTMESCOMPETENC = ( SELECT * FROM(SELECT GPE_VINCULOH.DTMESCOMPETENC FROM GPE_VINCULOH
                                                                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                  AND NRORG      = VM.NRORG
                                                                  AND NRVINCULOM = VM.NRVINCULOM 
                                                                  ORDER BY GPE_VINCULOH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  JOIN GPE_PESSOAH PE ON PE.NRPESSOA = VM.NRPESSOA 
                                    AND PE.NRORG = VM.NRORG 
                                    AND PE.DTMESCOMPETENC = (SELECT * FROM(SELECT GPE_PESSOAH.DTMESCOMPETENC FROM GPE_PESSOAH 
                                                              WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                AND NRORG = PE.NRORG
                                                                AND NRPESSOA = PE.NRPESSOA
                                                                ORDER BY GPE_PESSOAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  /*ESTRUTURA LEGAL*/
                  JOIN ESTRUTURAM EML ON EML.NRORG = VH.NRORG
                                          AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                  LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                          AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                          AND EHL.DTMESCOMPETENC = ( SELECT * FROM (SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                    WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = VH.NRORG
                                                                      AND NRESTRUTURAM = EML.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                                  AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
                  LEFT JOIN ESO_NAOPERIODICO ESONP ON ESONP.NRORG = VM.NRORG
                                            AND TRUNC(ESONP.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                            AND ESONP.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                            AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                                            AND ESONP.IDSTATUS IN('C','A')
                                            AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                                            AND ESONP.NRVINCULOM = VM.NRVINCULOM
                                            AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                  LEFT JOIN ESO_NAOPERIODFGTS NPFGTS ON NPFGTS.NRORG = ESONP.NRORG
                                                  AND NPFGTS.NRENVIO = ESONP.NRENVIO                                   
                  LEFT JOIN ESO_PERIODICO ESOPE ON ESOPE.NRORG = VM.NRORG
                                               AND TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                               AND ESOPE.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                               AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                                               AND ESOPE.IDSTATUS IN('C','A')
                                               AND ESOPE.NMEVENTO IN ('S-1200')
                                               AND ESOPE.NRCHAVE = VM.NRPESSOA
                                               AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                  LEFT JOIN ESO_PERIODFGTS PEFGTS ON PEFGTS.NRORG = ESOPE.NRORG
                                               AND PEFGTS.NRENVIO = ESOPE.NRENVIO
                  LEFT JOIN ESTRUTURAH LOT ON LOT.NRORG        = NVL(ESOPE.NRORG,ESONP.NRORG)
                                          AND LOT.NRESTRUTURAM = NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO)
                                          AND LOT.DTMESCOMPETENC = ( SELECT * FROM(SELECT ESTRUTURAH.DTMESCOMPETENC FROM ESTRUTURAH
                                                                    WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = LOT.NRORG
                                                                      AND NRESTRUTURAM = LOT.NRESTRUTURAM 
                                                                      ORDER BY ESTRUTURAH.DTMESCOMPETENC DESC)WHERE ROWNUM = 1)
                  /*CATEGORIA*/
                  JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
                  JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
                  WHERE VM.NRORG = :P_NRORG
                    AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                    AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                    AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL )
                    AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                  GROUP BY 
                    VM.NRVINCULOM,
                    PE.NRCPFPESSOA,
                    VM.NMVINCULOM,
                    VH.NRESTRUTLEGAL,
                    EHL.NMRAZSOCESTRUT,
                    EHL.CDCNPJESTRUT,
                    NVL(NPFGTS.VRBASEFGTS13,PEFGTS.VRBASEFGTS13),
                    NVL(ESOPE.DTMESCOMPETENC, ESONP.DTMESCOMPETENC),
                    SUBSTR(EHL.CDCNPJESTRUT, 0,8),
                    NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO),
                    NVL(LOT.CDFPAS,EHL.CDFPAS),
                    NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO),
                    NVL(NPFGTS.VRBASEFGTSMENSAL,PEFGTS.VRBASEFGTSMENSAL),
                    NVL(NPFGTS.VRBASEFGTS13,PEFGTS.VRBASEFGTS13),
                    VM.DTRESCISAOVINC,
                    CATEGTRAB.DSCATEGESOC,
                    CATEGTRAB.CDESOCIAL
                    ) PRI
      GROUP BY NRVINCULOM, NMVINCULOM, NRCPFPESSOA, NRLEGAL, RAZAOLEGAL, CNPJLEGAL, PRI.CDFPAS, PRI.CDTERCEIRO, CNPJRAIZ, PRI.NRESTRUTLOTACAO, PRI.VRBASEFGTSMENSAL, PRI.VRBASEFGTS13, PRI.DTRESCISAOVINC, PRI.DSCATEGESOC, PRI.CDESOCIAL)
      ORDER BY CNPJRAIZ, CNPJLEGAL, NMVINCULOM, DSCATEGESOC";
}
