<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class PreFechamentoIrrfRepository {
    
    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->retencaoTrabalhador = new RetencaoTrabalhador($entityManager);
    }
        
    public function getRetencaoTrabalhador($parameters) {
        return $this->retencaoTrabalhador->getRetencaoTrabalhador($parameters);
    }
    
    public function getEventosApuradosVinculoIrrf($parameters) {
        return $this->retencaoTrabalhador->getEventosApuradosVinculoIrrf($parameters);
    }
}

class RetencaoTrabalhador {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getRetencaoTrabalhador($parameters) {
      $sql = $this->entityManager->getConnection()->prepare(Queries::$queryRetencaoTrabalhador);
        $sql->execute(
            array(
                'P_NRORG'          => $parameters['NRORG'],
                'P_DTMESCOMPETENC' => $parameters['DTMESCOMPETENC'],
                'P_IDDIFERENCA'    => $parameters['IDDIFERENCA'],
                'P_IDRETENCAO'     => $parameters['IDRETENCAO'],
                'P_MODALIDADECAL'  => 1,
                'P_NRESTRUTLEGAL'  => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRESTRUTGEREN'  => is_array($parameters['NRESTRUTGEREN']) ? implode(",",$parameters['NRESTRUTGEREN']) : $parameters['NRESTRUTGEREN'],
                'P_NRESTRUTTOMAD'  => is_array($parameters['NRESTRUTTOMAD']) ? implode(",",$parameters['NRESTRUTTOMAD']) : $parameters['NRESTRUTTOMAD'],
                'P_NRVINCULO'      => null,
                'P_NRTIPOESTRUTGEREN' => $parameters['NRTIPOESTRUTGEREN'],
                'P_NRTIPOESTRUTTOMAD' => $parameters['NRTIPOESTRUTTOMAD'],
            )
        );
        return $sql->fetchAll();
    }
    
    public function getEventosApuradosVinculoIrrf($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryEventosApuradosVinculoIrrf);
        
        $sql->execute(
            array( 
                'P_NRORG'             => $parameters['NRORG'],
                'P_DTMESCOMPETENC'    => $parameters['DTMESCOMPETENC'],
                'P_DTOCORRENCIACALC'  => $parameters['DTOCORRENCIACALC'],
                'P_NRTPMODALIDCAL'    => $parameters['NRTPMODALIDCAL'],
                'P_NRVINCULOM'        => $parameters['NRVINCULOM'],
            )
        );
        return $sql->fetchAll();
    }
}

class Queries {
    
    static $queryRetencaoTrabalhador = "
/*queryRetencaoTrabalhador_cte*/
WITH
ULT_COMP_PESS AS (
    SELECT 
        NRORG, 
        NRPESSOA, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM GPE_PESSOAH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_DTMESCOMPETENC
    GROUP BY NRORG, NRPESSOA
),
ULT_COMP_VINC AS (
    SELECT 
        NRORG, 
        NRVINCULOM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM GPE_VINCULOH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_DTMESCOMPETENC
    GROUP BY NRORG, NRVINCULOM
),
ULT_COMP_ESTR AS (
    SELECT 
        NRORG, 
        NRESTRUTURAM, 
        MAX(DTMESCOMPETENC) AS DTMESCOMPETENC
    FROM ESTRUTURAH
    WHERE NRORG = :P_NRORG
      AND DTMESCOMPETENC <= :P_DTMESCOMPETENC
    GROUP BY NRORG, NRESTRUTURAM
),
VINCULOS AS (
    SELECT
      VM.NRORG,
      VM.NRPESSOA,
      VM.NRVINCULOM,
      VM.NMVINCULOM,
      VM.DTADMISSAOVINC,
      VM.DTRESCISAOVINC,
      VH.CDMATRICULAESOCIAL,
      VM.NRTIPOVINCULOM,
      CATEGTRAB.CDESOCIAL,
      CATEGTRAB.DSCATEGESOC,
      VH.NRESTRUTLEGAL,
      EHL.NMRAZSOCESTRUT NMESTRUTLEGAL,
      EHL.CDCNPJESTRUT,
      VH.NRESTRUTGEREN,
      EHG.NMESTRUTURAH NMESTRUTGEREN,
      ETM.NRESTRUTURAM NRESTRUTTOMAD,
      ETH.NMRAZSOCESTRUT NMESTRUTTOMAD,
      ETH.CDCNPJESTRUT CDCNPJTOMADOR,
      EP.NRTPAMBIENTE
    FROM GPE_VINCULOM VM
    JOIN ULT_COMP_VINC UCV ON UCV.NRORG = VM.NRORG
                          AND UCV.NRVINCULOM = VM.NRVINCULOM
    JOIN GPE_VINCULOH VH ON VH.NRORG = UCV.NRORG
                        AND VH.NRVINCULOM = UCV.NRVINCULOM
                        AND VH.DTMESCOMPETENC = UCV.DTMESCOMPETENC
    /*CATEGORIA*/
    JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
    JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
    /*ESTRUTURA LEGAL*/
    JOIN ESTRUTURAM EML ON EML.NRORG = VH.NRORG
                            AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
    JOIN ULT_COMP_ESTR UCEL ON UCEL.NRORG = EML.NRORG
                           AND UCEL.NRESTRUTURAM = EML.NRESTRUTURAM
    LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG = UCEL.NRORG
                            AND EHL.NRESTRUTURAM = UCEL.NRESTRUTURAM
                            AND EHL.DTMESCOMPETENC = UCEL.DTMESCOMPETENC
    /*ESTRUTURA GERENCIAL*/
    JOIN ESTRUTURAM EMG ON EMG.NRORG = VH.NRORG
                            AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
    JOIN ULT_COMP_ESTR UCEG ON UCEG.NRORG = EMG.NRORG
                           AND UCEG.NRESTRUTURAM = EMG.NRESTRUTURAM
    LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG = UCEG.NRORG
                            AND EHG.NRESTRUTURAM = UCEG.NRESTRUTURAM
                            AND EHG.DTMESCOMPETENC = UCEG.DTMESCOMPETENC
    /*ESTRUTURA TOMADOR*/                                    
    LEFT JOIN TIPOHIERARQORG TH ON (TH.NRORG = VH.NRORG OR TH.NRORG = 0)
          AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
          AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTTOMAD, 7)
    LEFT JOIN HIERARQUIAORG HO ON HO.NRORG = VH.NRORG
                              AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
                              AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
                              AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                              AND (HO.DTFIMVIGENCIA IS NULL OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                              AND HO.DTINIVIGENCIA =( select DTINIVIGENCIA from (SELECT HI.DTINIVIGENCIA
                                                        FROM HIERARQUIAORG HI
                                                      WHERE HI.NRORG = HO.NRORG
                                                        AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
                                                        AND HI.NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
                                                        AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                                                        AND (HI.DTFIMVIGENCIA IS NULL OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                                                        and HI.DTINIVIGENCIA is not null
                                                        order by HI.DTINIVIGENCIA desc ) where rownum = 1 )
    LEFT JOIN ESTRUTURAM ETM ON ETM.NRORG = HO.NRORG
                            AND ETM.NRESTRUTURAM = HO.NRESTRUTURAMSUP
    LEFT JOIN ULT_COMP_ESTR UCET ON UCET.NRORG = ETM.NRORG
                                AND UCET.NRESTRUTURAM = ETM.NRESTRUTURAM
    LEFT JOIN ESTRUTURAH ETH ON ETH.NRORG = UCET.NRORG
                            AND ETH.NRESTRUTURAM = UCET.NRESTRUTURAM
                            AND ETH.DTMESCOMPETENC = UCET.DTMESCOMPETENC
    /*PARAMETRO ESOCIAL*/
    JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                   AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
    /**/
    WHERE VM.NRORG = :P_NRORG
      AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC) )
      AND ( VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC OR VM.DTRESCISAOVINC IS NULL )
      AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
      AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
      AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
      AND ( INSTR(','||:P_NRESTRUTTOMAD||',', ','||ETM.NRESTRUTURAM||',' ) > 0 OR :P_NRESTRUTTOMAD IS NULL )
)
SELECT * FROM (
  SELECT
      RES.NRORG,
      RES.NRPESSOA,
      PH.NRCPFPESSOA,
      PH.NRCPFPESSOA||' - '||RES.NMVINCULOM PESSOA,
      RES.NRVINCULOM,
      RES.NMVINCULOM,
      RES.DTADMISSAOVINC,
      RES.DTRESCISAOVINC,
      RES.CDMATRICULAESOCIAL,
      NVL(RES.CDMATRICULAESOCIAL, RES.NRVINCULOM) MATRICULA,
      RES.NRTIPOVINCULOM,
      RES.CDESOCIAL CDCATEGESOC,
      RES.DSCATEGESOC,
      RES.NRESTRUTLEGAL,
      RES.NMESTRUTLEGAL,
      RES.CDCNPJESTRUT,
      SUBSTR(RES.CDCNPJESTRUT, 0,8) CNPJRAIZ,
      RES.NRESTRUTGEREN,
      RES.NMESTRUTGEREN,
      RES.NRESTRUTTOMAD,
      RES.NMESTRUTTOMAD,
      RES.CDCNPJTOMADOR,
      TO_CHAR(CAL.DTOCORRENCIACALC, 'DD/MM/YYYY') DTOCORRENCIACALC,
      TO_CHAR(CAL.DTOCORRENCIA, 'DD/MM/YYYY') DTPAGAMENTO,
      CAL.NRCALCULOFOLHA,
      CAL.NMTIPOMOVIMENT,
      CAL.NRTIPOMOVIMENT,
      RES.NRTPAMBIENTE,
      CAL.VRBASE,
      CAL.VRIRRF,
      ESOPE.IDSTATUS,
      ESOPE.NMEVENTO,
      ESOPE.NRENVIO,
      NVL(CAL.IDEDMDEV, RES.NRTIPOVINCULOM||'.'||RES.CDESOCIAL||'.'||CAL.NRCALCULOFOLHA) IDEDMDEV,
      SUM(NVL(ESOPE.VRBASEMENSAL,0) + NVL(ESOPE.VRBASE13,0)) VRBASE_ESO,
      SUM(NVL(ESOPE.VRVALORMENSAL,0) + NVL(ESOPE.VRVALOR13,0)) VRIRRF_ESO,
      CAL.VRBASE - SUM(NVL(ESOPE.VRBASEMENSAL,0) + NVL(ESOPE.VRBASE13,0)) DIFERENCA_BASE,
      CAL.VRIRRF - SUM(NVL(ESOPE.VRVALORMENSAL,0) + NVL(ESOPE.VRVALOR13,0)) DIFERENCA_IRRF
    FROM VINCULOS RES
    JOIN ULT_COMP_PESS UCP ON UCP.NRORG = RES.NRORG
                          AND UCP.NRPESSOA = RES.NRPESSOA
    JOIN GPE_PESSOAH PH ON PH.NRORG = UCP.NRORG
                       AND PH.NRPESSOA = UCP.NRPESSOA
                       AND PH.DTMESCOMPETENC = UCP.DTMESCOMPETENC
    JOIN (SELECT
              CF.NRORG,
              CF.NRCALCULOFOLHA,
              CF.DTOCORRENCIA DTOCORRENCIACALC,
              PAG.NRVINCULOM,
              PAG.DTOCORRENCIA,
              /*ICF.NREVENTOM,*/
              ICF.IDEDMDEV,
              SUM(CASE WHEN ICF.NREVENTOM IN (3080,3110,3140,3170,3175,3200,3212) THEN ICF.VREVENTOFOLHA ELSE 0 END) VRBASE,
              SUM(CASE WHEN ICF.NREVENTOM IN (1330,1340,1350,1360,1370,1380,1390,1395) THEN ICF.VREVENTOFOLHA ELSE 0 END) VRIRRF,
              TM.NMTIPOMOVIMENT,
              TM.NRTIPOMOVIMENT
            FROM FPA_ITECALCFOLHA PAG
            JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG = PAG.NRORG
                                     AND ICF.NRCALCULOFOLHA = PAG.NRCALCULOFOLHA
                                     AND ICF.NRVINCULOM = PAG.NRVINCULOM
                                     AND ICF.NREVENTOM IN (1330,1340,1350,1360,1370,1380,1390,1395,3080,3110,3140,3170,3175,3200,3212)
                                     AND TRUNC(ICF.DTOCORRENCIA,'MM') = :P_DTMESCOMPETENC
            JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = ICF.NRORG
                                    AND CF.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                    AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                    AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
            JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
            WHERE PAG.NRORG = :P_NRORG
              AND PAG.NREVENTOM IN (3030,3050)
              AND TRUNC(PAG.DTOCORRENCIA,'MM') = :P_DTMESCOMPETENC
            GROUP BY
              CF.NRORG,
              CF.NRCALCULOFOLHA,
              CF.DTOCORRENCIA,
              PAG.NRVINCULOM,
              PAG.DTOCORRENCIA,
              /*ICF.NREVENTOM,*/
              ICF.IDEDMDEV,
              TM.NMTIPOMOVIMENT,
              TM.NRTIPOMOVIMENT
          ) CAL ON CAL.NRORG = RES.NRORG
               AND CAL.NRVINCULOM = RES.NRVINCULOM
    LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                    ESOPE.NRTPAMBIENTE,
                    ESOPE.NRCHAVE,
                    ESOPE.NRESTRUTURAM,
                    ESOPE.NRORG,
                    ESOPE.NRENVIO,
                    ESOPE.IDSTATUS,
                    ESOPE.NRTABELA,
                    ESOPE.NMEVENTO,
                    RETIR.IDEDMDEV,
                    RETIR.CDCATEGTRAB,
                    SUM(NVL(RETIR.VRBASEMENSAL,0)) VRBASEMENSAL,
                    SUM(NVL(RETIR.VRBASE13,0)) VRBASE13,
                    SUM(NVL(RETIR.VRVALORMENSAL,0)) VRVALORMENSAL,
                    SUM(NVL(RETIR.VRVALOR13,0)) VRVALOR13,
                    EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE 
                JOIN ULT_COMP_ESTR UCE ON UCE.NRORG = ESOPE.NRORG
                                      AND UCE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG = UCE.NRORG
                                    AND EHPE.NRESTRUTURAM = UCE.NRESTRUTURAM
                                    AND EHPE.DTMESCOMPETENC = UCE.DTMESCOMPETENC
                JOIN ESO_PERIODRETIRRF RETIR ON RETIR.NRORG = ESOPE.NRORG
                                            AND RETIR.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND ESOPE.NMEVENTO = 'S-1210'
                GROUP BY ESOPE.DTMESCOMPETENC, ESOPE.NRTPAMBIENTE, ESOPE.NRCHAVE, ESOPE.NRENVIO, EHPE.CDCNPJESTRUT ,ESOPE.NRESTRUTURAM, ESOPE.NRORG, ESOPE.IDSTATUS, ESOPE.NRTABELA, ESOPE.NMEVENTO, RETIR.IDEDMDEV, RETIR.CDCATEGTRAB
            ) ESOPE ON ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CDCNPJESTRUT,1,8)
                   AND TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = TRUNC(CAL.DTOCORRENCIA, 'MM')
                   AND ESOPE.IDEDMDEV = CAL.IDEDMDEV
   GROUP BY
      RES.NRORG,
      RES.NRPESSOA,
      RES.NRVINCULOM,
      RES.NMVINCULOM,
      RES.DTADMISSAOVINC,
      RES.DTRESCISAOVINC,
      RES.CDMATRICULAESOCIAL,
      RES.NRTIPOVINCULOM,
      RES.CDESOCIAL,
      RES.DSCATEGESOC,
      PH.NRCPFPESSOA,
      RES.NRESTRUTLEGAL,
      RES.NMESTRUTLEGAL,
      RES.CDCNPJESTRUT,
      SUBSTR(RES.CDCNPJESTRUT, 0,8),
      RES.NRESTRUTGEREN,
      RES.NMESTRUTGEREN,
      RES.NRESTRUTTOMAD,
      RES.NMESTRUTTOMAD,
      RES.CDCNPJTOMADOR,
      TO_CHAR(CAL.DTOCORRENCIACALC, 'DD/MM/YYYY'),
      TO_CHAR(CAL.DTOCORRENCIA, 'DD/MM/YYYY'),
      CAL.NRCALCULOFOLHA,
      CAL.NMTIPOMOVIMENT,
      CAL.NRTIPOMOVIMENT,
      RES.NRTPAMBIENTE,
      CAL.VRBASE,
      CAL.VRIRRF,
      ESOPE.IDSTATUS,
      ESOPE.NMEVENTO,
      ESOPE.NRENVIO,
      NVL(CAL.IDEDMDEV, RES.NRTIPOVINCULOM||'.'||RES.CDESOCIAL||'.'||CAL.NRCALCULOFOLHA)
    )
WHERE ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_IRRF) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_IRRF) > 0.05 ) )
      )
AND ( :P_IDRETENCAO = 'N' OR ( :P_IDRETENCAO = 'S' AND  ABS(VRIRRF) + ABS(VRIRRF_ESO) > 0  ) )";
    
    static $queryEventosApuradosVinculoIrrf = "
/*queryEventosApuradosVinculoIrrf*/
SELECT
       CF.NRCALCULOFOLHA||' - '||TM.NMTIPOMOVIMENT||' - '||TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY')||' - Ocorrência:'||CF.NROCORRECAL PROCESSO,
       EH.NREVENTOM,
       EH.NMEVENTOH,
       TO_CHAR(CF.DTOCORRENCIA, 'MM/YYYY') PERIODO,
       TO_CHAR(ICF.DTOCORRENCIA, 'DD/MM/YYYY') DTOCORRENCIA,
       CF.NROCORRECAL,
       ICF.VREVENTOFOLHA,
       DECODE(EH.IDEVENTODEMONST,'S','3',DECODE(EM.IDTIPOEVENTO,'PROVENTO','1','DESCONTO','2','ENCARGO','3','TOTAL','3')) IDTPRUBRICA,
       RU.CDINCIDEIRRF,
       DECODE(EH.NRNATURUBR, NULL, 'Sem parametrização', IRRF.DSINCIDIRRF) INCIDEIRRF
  FROM FPA_ITECALCFOLHA ICF
  JOIN FPA_CALCULOFOLHA CF 
    ON CF.NRORG = ICF.NRORG
   AND CF.NRCALCULOFOLHA  = ICF.NRCALCULOFOLHA
   AND CF.NRTIPOMOVIMENT IN (1,2,4,10,19)
   AND CF.DTOCORRENCIA    = :P_DTOCORRENCIACALC
   AND CF.NRTPMODALIDCAL  = :P_NRTPMODALIDCAL
  JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  JOIN FPA_EVENTOM EM ON (EM.NREVENTOM = ICF.NREVENTOM)
  JOIN FPA_EVENTOH EH ON (EH.NREVENTOM = EM.NREVENTOM)
  JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NREVENTOM
          FROM FPA_EVENTOH 
         WHERE DTMESCOMPETENC <= :P_DTOCORRENCIACALC
         GROUP BY NREVENTOM) EHATUAL 
    ON ( EHATUAL.NREVENTOM = EH.NREVENTOM
   AND EHATUAL.DTMESCOMPETENC = EH.DTMESCOMPETENC)
  LEFT JOIN ESO_RUBRICA RU ON (RU.NRORG = ICF.NRORG OR RU.NRORG = 0)
                          AND RU.NREVENTOM = EM.NREVENTOM
                          AND RU.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
  LEFT JOIN INCIDENCIAIRRF IRRF ON IRRF.CDESOCIAL = RU.CDINCIDEIRRF
  WHERE ICF.NRORG = :P_NRORG
    AND ICF.NRVINCULOM = :P_NRVINCULOM
    AND (CF.NRTIPOMOVIMENT <> 1 OR ( ICF.NREVENTOM NOT IN (1330,1340,1350,1360,1370,1380,1390,1395,3080,3110,3140,3170,3175,3200,3212) OR (ICF.NREVENTOM IN (1330,1340,1350,1360,1370,1380,1390,1395,3080,3110,3140,3170,3175,3200,3212) AND TRUNC(ICF.DTOCORRENCIA,'MM') = :P_DTMESCOMPETENC)))
    AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA PAG
                 WHERE PAG.NRORG = ICF.NRORG
                   AND PAG.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                   AND PAG.NRVINCULOM = ICF.NRVINCULOM
                   AND PAG.NREVENTOM IN (3030,3050))
    ";

}